@@ -11,7 +11,6 @@ The ...Update classes allow editing of a, possibly incomplete, game score.
 
 """
 from ast import literal_eval
-import re
 
 from solentware_base.core.record import KeyData, Value, ValueText, Record
 from solentware_base.core.segmentsize import SegmentSize
@@ -53,7 +52,6 @@ from .filespec import (
     SQUAREMOVE_FIELD_DEF,
     GAMES_FILE_DEF,
     REPERTOIRE_FILE_DEF,
-    OPENING_ERROR_FIELD_DEF,
     PGN_DATE_FIELD_DEF,
     VARIATION_FIELD_DEF,
     ENGINE_FIELD_DEF,
@@ -69,39 +67,32 @@ PLAYER_NAME_TAGS = frozenset((TAG_WHITE, TAG_BLACK))
 
 
 class ChessRecordError(Exception):
-    pass
+    """Exception class for chessrecor module."""
 
 
 class ChessDBkeyGame(KeyData):
-
     """Primary key of chess game."""
 
     def __eq__(self, other):
         """Return (self == other).  Attributes are compared explicitly."""
-        try:
-            return self.recno == other.recno
-        except:
-            return False
+        return self.recno == other.recno
 
     def __ne__(self, other):
         """Return (self != other).  Attributes are compared explicitly."""
-        try:
-            return self.recno != other.recno
-        except:
-            return True
+        return self.recno != other.recno
 
 
-class ChessDBvaluePGN(Value):
-
+class ChessDBvaluePGN(PGN, Value):
     """Methods common to all chess PGN data classes."""
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, **kwargs):
+        """Delegate then initialize collected game."""
+        super().__init__(**kwargs)
         self.collected_game = None
 
     @staticmethod
     def encode_move_number(key):
-        """Return base 256 string for integer with left-end most significant."""
+        """Return base 256 string for integer, left-end most significant."""
         return key.to_bytes(2, byteorder="big")
 
     def load(self, value):
@@ -110,11 +101,10 @@ class ChessDBvaluePGN(Value):
 
     def pack_value(self):
         """Return PGN text for game."""
-        return repr("".join(self.collected_game._text))
+        return repr("".join(self.collected_game.pgn_text))
 
 
-class ChessDBvalueGame(PGN, ChessDBvaluePGN):
-
+class ChessDBvalueGame(ChessDBvaluePGN):
     """Chess game data.
 
     Data is indexed by PGN Seven Tag Roster tags.
@@ -127,9 +117,9 @@ class ChessDBvalueGame(PGN, ChessDBvaluePGN):
 
     def pack(self):
         """Return PGN text and indexes for game."""
-        v = super(ChessDBvalueGame, self).pack()
-        index = v[1]
-        tags = self.collected_game._tags
+        value = super().pack()
+        index = value[1]
+        tags = self.collected_game.pgn_tags
         for field in tags:
             if field in PLAYER_NAME_TAGS:
 
@@ -146,18 +136,15 @@ class ChessDBvalueGame(PGN, ChessDBvaluePGN):
             index[PGN_DATE_FIELD_DEF] = [
                 tags[TAG_DATE].replace(*SPECIAL_TAG_DATE)
             ]
-        return v
+        return value
 
 
 class ChessDBrecordGame(Record):
-
     """Chess game record customised for displaying the game score and tags."""
 
     def __init__(self):
-        """Extend with move number encode and decode methods"""
-        super(ChessDBrecordGame, self).__init__(
-            ChessDBkeyGame, ChessDBvalueGame
-        )
+        """Extend with move number encode and decode methods."""
+        super().__init__(ChessDBkeyGame, ChessDBvalueGame)
 
     def clone(self):
         """Return copy of ChessDBrecordGame instance.
@@ -169,12 +156,12 @@ class ChessDBrecordGame(Record):
 
         """
         # are conditions for deleting this method in place?
-        clone = super(ChessDBrecordGame, self).clone()
+        clone = super().clone()
         return clone
 
     @staticmethod
     def decode_move_number(skey):
-        """Return integer from base 256 string with left-end most significant."""
+        """Return integer from base 256 string, left-end most significant."""
         return int.from_bytes(skey, byteorder="big")
 
     def delete_record(self, database, dbset):
@@ -198,7 +185,7 @@ class ChessDBrecordGame(Record):
 
         The keys for the secondary databases in a ChessDatabase instance are
         embedded in, or derived from, the PGN string for the game.  All
-        except the positions are held in self.value.collected_game._tags.
+        except the positions are held in self.value.collected_game.pgn_tags.
         Multiple position keys can arise becuse all repetitions of a
         position are of interest.  The partial argument is used to select
         the relevant keys.  The position is in partial and the keys will
@@ -209,13 +196,15 @@ class ChessDBrecordGame(Record):
         if dbname != POSITIONS_FIELD_DEF:
             if dbname == GAMES_FILE_DEF:
                 return [(self.key.recno, self.srvalue)]
-            elif dbname in self.value.collected_game._tags:
+            if dbname in self.value.collected_game.pgn_tags:
                 return [
-                    (self.value.collected_game._tags[dbname], self.key.pack())
+                    (
+                        self.value.collected_game.pgn_tags[dbname],
+                        self.key.pack(),
+                    )
                 ]
-            else:
-                return []
-        if partial == None:
+            return []
+        if partial is None:
             return []
 
         moves = self.value.moves
@@ -225,16 +214,16 @@ class ChessDBrecordGame(Record):
         keys = []
         convert_format = datasource.dbhome.db_compatibility_hack
 
-        p = tuple(partial)
-        for mt in moves:
-            if mt == START_RAV:
+        elements = tuple(partial)
+        for token in moves:
+            if token == START_RAV:
                 rav += 1
-            elif mt == END_RAV:
+            elif token == END_RAV:
                 rav -= 1
-            elif mt == NON_MOVE:
+            elif token == NON_MOVE:
                 pass
             else:
-                if mt[-1] == p:
+                if token[-1] == elements:
                     record = (partial, None)
                     keys.append(convert_format(record, gamekey))
             ref += 1
@@ -250,7 +239,6 @@ class ChessDBrecordGame(Record):
 
 
 class ChessDBrecordGameText(Record):
-
     """Chess game record customised for processing the game score as text.
 
     Used to export games or repertoires from a database in the 'Import Format',
@@ -259,8 +247,8 @@ class ChessDBrecordGameText(Record):
     """
 
     def __init__(self):
-        """Extend with move number encode and decode methods"""
-        super(ChessDBrecordGameText, self).__init__(ChessDBkeyGame, ValueText)
+        """Extend with move number encode and decode methods."""
+        super().__init__(ChessDBkeyGame, ValueText)
 
     def clone(self):
         """Return copy of ChessDBrecordGameText instance.
@@ -272,12 +260,12 @@ class ChessDBrecordGameText(Record):
 
         """
         # are conditions for deleting this method in place?
-        clone = super(ChessDBrecordGameText, self).clone()
+        clone = super().clone()
         return clone
 
     @staticmethod
     def decode_move_number(skey):
-        """Return integer from base 256 string with left-end most significant."""
+        """Return integer from base 256 string, left-end most significant."""
         return int.from_bytes(skey, byteorder="big")
 
     def delete_record(self, database, dbset):
@@ -306,7 +294,6 @@ class ChessDBrecordGameText(Record):
 
 
 class ChessDBvalueGameTags(ChessDBvalueGame):
-
     """Chess game data excluding PGN movetext but including PGN Tags."""
 
     def __init__(self):
@@ -319,7 +306,7 @@ class ChessDBvalueGameTags(ChessDBvalueGame):
         Added to support Find and Where classes.
 
         """
-        return self.collected_game._tags.get(fieldname, None)
+        return self.collected_game.pgn_tags.get(fieldname, None)
 
     # def get_field_values(self, fieldname):
     #    """Return tuple of field values for fieldname.
@@ -352,18 +339,14 @@ class ChessDBvalueGameTags(ChessDBvalueGame):
 
 
 class ChessDBrecordGameTags(Record):
-
-    """Chess game record customised for displaying tag information for a game."""
+    """Chess game record customised to display tag information for a game."""
 
     def __init__(self):
-        """Extend with move number encode and decode methods"""
-        super(ChessDBrecordGameTags, self).__init__(
-            ChessDBkeyGame, ChessDBvalueGameTags
-        )
+        """Extend with move number encode and decode methods."""
+        super().__init__(ChessDBkeyGame, ChessDBvalueGameTags)
 
 
 class ChessDBrecordGamePosition(Record):
-
     """Chess game record customised for displaying the game score only.
 
     Much of the game structure to be represented in the row display is held
@@ -374,10 +357,8 @@ class ChessDBrecordGamePosition(Record):
     """
 
     def __init__(self):
-        """Extend with move number encode and decode methods"""
-        super(ChessDBrecordGamePosition, self).__init__(
-            ChessDBkeyGame, ValueText
-        )
+        """Extend with move number encode and decode methods."""
+        super().__init__(ChessDBkeyGame, ValueText)
 
     def clone(self):
         """Return copy of ChessDBrecordGamePosition instance.
@@ -389,12 +370,12 @@ class ChessDBrecordGamePosition(Record):
 
         """
         # are conditions for deleting this method in place?
-        clone = super(ChessDBrecordGamePosition, self).clone()
+        clone = super().clone()
         return clone
 
     @staticmethod
     def decode_move_number(skey):
-        """Return integer from base 256 string with left-end most significant."""
+        """Return integer from base 256 string, left-end most significant."""
         return int.from_bytes(skey, byteorder="big")
 
     def delete_record(self, database, dbset):
@@ -463,8 +444,7 @@ class _GameUpdate(GameUpdate):
         return comment.replace(END_COMMENT, HIDE_END_COMMENT)
 
 
-class ChessDBvaluePGNUpdate(PGN, ChessDBvaluePGN):
-
+class ChessDBvaluePGNUpdate(ChessDBvaluePGN):
     """Chess game data with position, piece location, and PGN Tag, indexes."""
 
     # Replaces ChessDBvaluePGNUpdate and ChessDBvalueGameImport which had been
@@ -488,11 +468,11 @@ class ChessDBvaluePGNUpdate(PGN, ChessDBvaluePGN):
     # the version of pack() below.
     def pack(self):
         """Return PGN text and indexes for game."""
-        v = super().pack()
-        index = v[1]
-        cg = self.collected_game
+        value = super().pack()
+        index = value[1]
+        game = self.collected_game
         if self.do_full_indexing():
-            tags = cg._tags
+            tags = game.pgn_tags
             for field in SEVEN_TAG_ROSTER:
                 if field in PLAYER_NAME_TAGS:
 
@@ -513,10 +493,10 @@ class ChessDBvaluePGNUpdate(PGN, ChessDBvaluePGN):
                     except KeyError:
                         if field in tags:
                             raise
-            index[POSITIONS_FIELD_DEF] = cg.positionkeys
-            index[PIECESQUAREMOVE_FIELD_DEF] = cg.piecesquaremovekeys
-            index[PIECEMOVE_FIELD_DEF] = cg.piecemovekeys
-            index[SQUAREMOVE_FIELD_DEF] = cg.squaremovekeys
+            index[POSITIONS_FIELD_DEF] = game.positionkeys
+            index[PIECESQUAREMOVE_FIELD_DEF] = game.piecesquaremovekeys
+            index[PIECEMOVE_FIELD_DEF] = game.piecemovekeys
+            index[SQUAREMOVE_FIELD_DEF] = game.squaremovekeys
             try:
                 index[PGN_DATE_FIELD_DEF] = [
                     tags[TAG_DATE].replace(*SPECIAL_TAG_DATE)
@@ -526,7 +506,7 @@ class ChessDBvaluePGNUpdate(PGN, ChessDBvaluePGN):
                     raise
         else:
             index[SOURCE_FIELD_DEF] = [self.gamesource]
-        return v
+        return value
 
     def set_game_source(self, source):
         """Set the index value to use if full indexing is not to be done."""
@@ -548,12 +528,11 @@ class ChessDBvaluePGNUpdate(PGN, ChessDBvaluePGN):
     def is_error_comment_present(self):
         """Return True if an {Error: ...} comment is in the PGN text."""
         return START_COMMENT + ERROR_START_COMMENT in "".join(
-            self.collected_game._text
+            self.collected_game.pgn_text
         )
 
 
 class ChessDBrecordGameUpdate(Record):
-
     """Chess game record customized for editing database records.
 
     Used to edit or insert a single record by typing in a widget.
@@ -561,10 +540,8 @@ class ChessDBrecordGameUpdate(Record):
     """
 
     def __init__(self):
-        """Extend with move number encode and decode methods"""
-        super(ChessDBrecordGameUpdate, self).__init__(
-            ChessDBkeyGame, ChessDBvaluePGNUpdate
-        )
+        """Extend with move number encode and decode methods."""
+        super().__init__(ChessDBkeyGame, ChessDBvaluePGNUpdate)
 
     def clone(self):
         """Return copy of ChessDBrecordGameUpdate instance.
@@ -576,12 +553,12 @@ class ChessDBrecordGameUpdate(Record):
 
         """
         # are conditions for deleting this method in place?
-        clone = super(ChessDBrecordGameUpdate, self).clone()
+        clone = super().clone()
         return clone
 
     @staticmethod
     def decode_move_number(skey):
-        """Return integer from base 256 string with left-end most significant."""
+        """Return integer from base 256 string, left-end most significant."""
         return int.from_bytes(skey, byteorder="big")
 
     def get_keys(self, datasource=None, partial=None):
@@ -589,7 +566,7 @@ class ChessDBrecordGameUpdate(Record):
 
         The keys for the secondary databases in a ChessDatabase instance are
         embedded in, or derived from, the PGN string for the game.  All
-        except the positions are held in self.value.collected_game._tags.
+        except the positions are held in self.value.collected_game.pgn_tags.
         Multiple position keys can arise becuse all repetitions of a
         position are of interest.  The partial argument is used to select
         the relevant keys.  The position is in partial and the keys will
@@ -600,13 +577,15 @@ class ChessDBrecordGameUpdate(Record):
         if dbname != POSITIONS_FIELD_DEF:
             if dbname == GAMES_FILE_DEF:
                 return [(self.key.recno, self.srvalue)]
-            elif dbname in self.value.collected_game._tags:
+            if dbname in self.value.collected_game.pgn_tags:
                 return [
-                    (self.value.collected_game._tags[dbname], self.key.pack())
+                    (
+                        self.value.collected_game.pgn_tags[dbname],
+                        self.key.pack(),
+                    )
                 ]
-            else:
-                return []
-        if partial == None:
+            return []
+        if partial is None:
             return []
 
         moves = self.value.moves
@@ -616,42 +595,23 @@ class ChessDBrecordGameUpdate(Record):
         keys = []
         convert_format = datasource.dbhome.db_compatibility_hack
 
-        p = tuple(partial)
-        for mt in moves:
-            if mt == START_RAV:
+        elements = tuple(partial)
+        for token in moves:
+            if token == START_RAV:
                 rav += 1
-            elif mt == END_RAV:
+            elif token == END_RAV:
                 rav -= 1
-            elif mt == NON_MOVE:
+            elif token == NON_MOVE:
                 pass
             else:
-                if mt[-1] == p:
+                if token[-1] == elements:
                     record = (partial, None)
                     keys.append(convert_format(record, gamekey))
             ref += 1
         return keys
 
-    def load_instance(self, database, dbset, dbname, record):
-        """Extend to set source for game if necessary."""
-        super(ChessDBrecordGameUpdate, self).load_instance(
-            database, dbset, dbname, record
-        )
-
-        # Never called because attribute is not bound anywhere and no
-        # exceptions are seen ever.
-        # Until ..tools.chesstab-4-1-1_castling-option-correction written, and
-        # following code commented.  I assume the idea made sense once!
-        # Might as well let superclass method be used directly.
-        # if self.value.callbacktried:
-        #    pass
-        # elif self.value.callbacktried == None:
-        #    pass
-        # elif not self.value.callbacktried:
-        #    self.value.set_game_source(record[0])
-
 
 class ChessDBrecordGameImport(Record):
-
     """Chess game record customised for importing games from PGN files.
 
     Used to import multiple records from a PGN file.
@@ -659,10 +619,8 @@ class ChessDBrecordGameImport(Record):
     """
 
     def __init__(self):
-        """Customise Record with chess database import key and value classes"""
-        super(ChessDBrecordGameImport, self).__init__(
-            ChessDBkeyGame, ChessDBvaluePGNUpdate
-        )
+        """Customise Record with chess database key and value classes."""
+        super().__init__(ChessDBkeyGame, ChessDBvaluePGNUpdate)
 
     def import_pgn(self, database, source, sourcename, reporter=None):
         """Update database with games read from source."""
@@ -705,68 +663,46 @@ class ChessDBrecordGameImport(Record):
 
 
 class ChessDBkeyPartial(KeyData):
-
     """Primary key of partial position record."""
 
 
 class ChessDBvaluePartial(CQLStatement, Value):
-
     """Partial position data."""
 
-    def __init__(self):
-        super(ChessDBvaluePartial, self).__init__()
-
     def __eq__(self, other):
         """Return (self == other).  Attributes are compared explicitly."""
-        try:
-            if (
-                self.get_name_statement_text()
-                != other.get_name_statement_text()
-            ):
-                return False
-            else:
-                return True
-        except:
+        if self.get_name_statement_text() != other.get_name_statement_text():
             return False
+        return True
 
     def __ne__(self, other):
         """Return (self != other).  Attributes are compared explicitly."""
-        try:
-            if (
-                self.get_name_statement_text()
-                == other.get_name_statement_text()
-            ):
-                return False
-            else:
-                return True
-        except:
-            return True
+        if self.get_name_statement_text() == other.get_name_statement_text():
+            return False
+        return True
 
     def load(self, value):
-        """Set partial position from value"""
+        """Set partial position from value."""
         self.process_statement(literal_eval(value))
 
     def pack_value(self):
-        """Return partial position value"""
+        """Return partial position value."""
         return repr(self.get_name_statement_text())
 
     def pack(self):
         """Extend, return partial position record and index data."""
-        v = super().pack()
-        index = v[1]
+        value = super().pack()
+        index = value[1]
         index[PARTIALPOSITION_NAME_FIELD_DEF] = [self.get_name_text()]
-        return v
+        return value
 
 
 class ChessDBrecordPartial(Record):
-
     """Partial position record."""
 
     def __init__(self):
         """Extend as a partial position record."""
-        super(ChessDBrecordPartial, self).__init__(
-            ChessDBkeyPartial, ChessDBvaluePartial
-        )
+        super().__init__(ChessDBkeyPartial, ChessDBvaluePartial)
 
     def get_keys(self, datasource=None, partial=None):
         """Return list of (key, value) tuples.
@@ -777,8 +713,7 @@ class ChessDBrecordPartial(Record):
         """
         if datasource.dbname == PARTIALPOSITION_NAME_FIELD_DEF:
             return [(self.value.get_name_text(), self.key.pack())]
-        else:
-            return super().get_keys(datasource=datasource, partial=partial)
+        return super().get_keys(datasource=datasource, partial=partial)
 
     def load_value(self, value):
         """Load self.value from value which is repr(<data>).
@@ -794,7 +729,6 @@ class ChessDBrecordPartial(Record):
 
 # Not quite sure what customization needed yet
 class ChessDBvalueRepertoire(PGN, Value):
-
     """Repertoire data using custom non-standard tags in PGN format."""
 
     def __init__(self, game_class=GameRepertoireDisplayMoves):
@@ -809,7 +743,6 @@ class ChessDBvalueRepertoire(PGN, Value):
 
 # Not quite sure what customization needed yet
 class ChessDBvalueRepertoireTags(ChessDBvalueRepertoire):
-
     """Repertoire data using custom non-standard tags in PGN format."""
 
     def __init__(self):
@@ -818,8 +751,7 @@ class ChessDBvalueRepertoireTags(ChessDBvalueRepertoire):
 
 
 # Not quite sure what customization needed yet
-class ChessDBvalueRepertoireUpdate(PGN, ChessDBvaluePGN):
-
+class ChessDBvalueRepertoireUpdate(ChessDBvaluePGN):
     """Repertoire data using custom non-standard tags in PGN format."""
 
     def __init__(self):
@@ -829,30 +761,31 @@ class ChessDBvalueRepertoireUpdate(PGN, ChessDBvaluePGN):
 
     def pack(self):
         """Return PGN text and indexes for game."""
-        v = super(ChessDBvalueRepertoireUpdate, self).pack()
-        index = v[1]
-        tags = self.collected_game._tags
+        value = super().pack()
+        index = value[1]
+        tags = self.collected_game.pgn_tags
         if self.collected_game.is_pgn_valid():
             index[TAG_OPENING] = [tags[TAG_OPENING]]
         elif tags[TAG_OPENING]:
             index[TAG_OPENING] = [tags[TAG_OPENING]]
         else:
             index[TAG_OPENING] = [self.gamesource]
-        return v
+        return value
 
     def set_game_source(self, source):
-        """Set game source (the PGN file name or '')"""
+        """Set game source (the PGN file name or '')."""
         self.gamesource = source
 
 
 # Not quite sure what customization needed yet
 class ChessDBrecordRepertoire(ChessDBrecordGame):
-
     """Repertoire record customised for exporting repertoire information."""
 
     def __init__(self):
-        """Extend with move number encode and decode methods"""
+        """Extend with move number encode and decode methods."""
         # Skip the immediate superclass __init__ to fix key and value classes
+        # pylint bad-super-call message given.
+        # pylint super-with-arguments message given.
         super(ChessDBrecordGame, self).__init__(
             ChessDBkeyGame, ChessDBvalueRepertoire
         )
@@ -860,12 +793,13 @@ class ChessDBrecordRepertoire(ChessDBrecordGame):
 
 # Not quite sure what customization needed yet
 class ChessDBrecordRepertoireTags(ChessDBrecordGameTags):
-
-    """Repertoire record customised for displaying repertoire tag information."""
+    """Repertoire record customised to display repertoire tag information."""
 
     def __init__(self):
-        """Extend with move number encode and decode methods"""
+        """Extend with move number encode and decode methods."""
         # Skip the immediate superclass __init__ to fix key and value classes
+        # pylint bad-super-call message given.
+        # pylint super-with-arguments message given.
         super(ChessDBrecordGameTags, self).__init__(
             ChessDBkeyGame, ChessDBvalueRepertoireTags
         )
@@ -873,12 +807,13 @@ class ChessDBrecordRepertoireTags(ChessDBrecordGameTags):
 
 # Not quite sure what customization needed yet
 class ChessDBrecordRepertoireUpdate(ChessDBrecordGameUpdate):
-
     """Repertoire record customized for editing repertoire records."""
 
     def __init__(self):
-        """Extend with move number encode and decode methods"""
+        """Extend with move number encode and decode methods."""
         # Skip the immediate superclass __init__ to fix key and value classes
+        # pylint bad-super-call message given.
+        # pylint super-with-arguments message given.
         super(ChessDBrecordGameUpdate, self).__init__(
             ChessDBkeyGame, ChessDBvalueRepertoireUpdate
         )
@@ -888,7 +823,7 @@ class ChessDBrecordRepertoireUpdate(ChessDBrecordGameUpdate):
 
         The keys for the secondary databases in a ChessDatabase instance are
         embedded in, or derived from, the PGN string for the game.  All
-        except the positions are held in self.value.collected_game._tags.
+        except the positions are held in self.value.collected_game.pgn_tags.
         Multiple position keys can arise becuse all repetitions of a
         position are of interest.  The partial argument is used to select
         the relevant keys.  The position is in partial and the keys will
@@ -898,31 +833,30 @@ class ChessDBrecordRepertoireUpdate(ChessDBrecordGameUpdate):
         dbname = datasource.dbname
         if dbname == REPERTOIRE_FILE_DEF:
             return [(self.key.recno, self.srvalue)]
-        elif dbname in self.value.collected_game._tags:
-            return [(self.value.collected_game._tags[dbname], self.key.pack())]
-        else:
-            return []
+        if dbname in self.value.collected_game.pgn_tags:
+            return [
+                (self.value.collected_game.pgn_tags[dbname], self.key.pack())
+            ]
+        return []
 
 
 class ChessDBvalueAnalysis(Analysis, Value):
-
     """Chess engine analysis data for a position."""
 
     def __init__(self):
-        """ """
+        """Delegate."""
         super().__init__()
 
     def pack(self):
         """Extend, return analysis record and index data."""
-        v = super().pack()
-        index = v[1]
+        value = super().pack()
+        index = value[1]
         index[VARIATION_FIELD_DEF] = [self.position]
-        index[ENGINE_FIELD_DEF] = [k for k in self.scale]
-        return v
+        index[ENGINE_FIELD_DEF] = list(self.scale)
+        return value
 
 
 class ChessDBrecordAnalysis(Record):
-
     """Chess game record customised for chess engine analysis data.
 
     No index values are derived from PGN move text, so there is no advantage in
@@ -937,68 +871,52 @@ class ChessDBrecordAnalysis(Record):
 
 
 class ChessDBkeyQuery(KeyData):
-
     """Primary key of game selection rule record."""
 
 
 class ChessDBvalueQuery(QueryStatement, Value):
-
     """Game selection rule data."""
 
-    def __init__(self):
-        super(ChessDBvalueQuery, self).__init__()
-
     def __eq__(self, other):
         """Return (self == other).  Attributes are compared explicitly."""
-        try:
-            if (
-                self.get_name_query_statement_text()
-                != other.get_name_query_statement_text()
-            ):
-                return False
-            else:
-                return True
-        except:
+        if (
+            self.get_name_query_statement_text()
+            != other.get_name_query_statement_text()
+        ):
             return False
+        return True
 
     def __ne__(self, other):
         """Return (self != other).  Attributes are compared explicitly."""
-        try:
-            if (
-                self.get_name_query_statement_text()
-                == other.get_name_query_statement_text()
-            ):
-                return False
-            else:
-                return True
-        except:
-            return True
+        if (
+            self.get_name_query_statement_text()
+            == other.get_name_query_statement_text()
+        ):
+            return False
+        return True
 
     def load(self, value):
-        """Set game selection rule from value"""
+        """Set game selection rule from value."""
         self.process_query_statement(literal_eval(value))
 
     def pack_value(self):
-        """Return gameselection rule value"""
+        """Return gameselection rule value."""
         return repr(self.get_name_query_statement_text())
 
     def pack(self):
         """Extend, return game selection rule record and index data."""
-        v = super().pack()
-        index = v[1]
+        value = super().pack()
+        index = value[1]
         index[RULE_FIELD_DEF] = [self.get_name_text()]
-        return v
+        return value
 
 
 class ChessDBrecordQuery(Record):
-
     """Game selection rule record."""
 
     def __init__(self):
         """Extend as a game selection rule record."""
-        super(ChessDBrecordQuery, self).__init__(
-            ChessDBkeyQuery, ChessDBvalueQuery
-        )
+        super().__init__(ChessDBkeyQuery, ChessDBvalueQuery)
 
     def get_keys(self, datasource=None, partial=None):
         """Return list of (key, value) tuples.
@@ -1009,8 +927,7 @@ class ChessDBrecordQuery(Record):
         """
         if datasource.dbname == RULE_FIELD_DEF:
             return [(self.value.get_name_text(), self.key.pack())]
-        else:
-            return super().get_keys(datasource=datasource, partial=partial)
+        return super().get_keys(datasource=datasource, partial=partial)
 
     def load_value(self, value):
         """Load self.value from value which is repr(<data>).
@@ -1025,31 +942,23 @@ class ChessDBrecordQuery(Record):
 
 
 class ChessDBkeyEngine(KeyData):
-
     """Primary key of chess engine record."""
 
 
 class ChessDBvalueEngine(Engine, Value):
-
     """Game selection rule data."""
 
-    def __init__(self):
-        super(ChessDBvalueEngine, self).__init__()
-
     def pack(self):
         """Extend, return game selection rule record and index data."""
-        v = super().pack()
-        index = v[1]
+        value = super().pack()
+        index = value[1]
         index[COMMAND_FIELD_DEF] = [self.get_name_text()]
-        return v
+        return value
 
 
 class ChessDBrecordEngine(Record):
-
     """Chess engine record."""
 
     def __init__(self):
         """Extend as a game selection rule record."""
-        super(ChessDBrecordEngine, self).__init__(
-            ChessDBkeyEngine, ChessDBvalueEngine
-        )
+        super().__init__(ChessDBkeyEngine, ChessDBvalueEngine)
