@@ -20,18 +20,16 @@ from chessql.core.constants import (
     PIECE_NAMES,
     SQUARE_DESIGNATOR_SEPARATOR,
     FILE_NAMES,
-    RANK_NAMES,
+    CQL_RANK_NAMES,
 )
 from chessql.core.node import Node
 from chessql.core.piecedesignator import PieceDesignator
 
-from .constants import (
-    MAP_CQL_PIECE_TO_PIECES,
-)
+from ..basecore.rayfilter import RayFilter
 
 
 class CQLNodeError(Exception):
-    pass
+    """Exception class for cqlnode module."""
 
 
 class CQLNode(Node):
@@ -43,6 +41,7 @@ class CQLNode(Node):
     """
 
     def __init__(self, *a, **k):
+        """Delegate then initialize node state."""
         super().__init__(*a, **k)
 
         # May get rid of 'where' because components should not be needed again
@@ -51,17 +50,19 @@ class CQLNode(Node):
         self.data = None
         self.where = None
 
-    def transform_piece_designators(self, fs_filter):
+    @staticmethod
+    def transform_piece_designators(fs_filter):
         """Apply transforms to piece designators in CQL statement."""
         children = fs_filter.children
-        for n in fs_filter.node.children:
-            children.append(FSNode(n))
-            r = n.transform_piece_designators(children[-1])
-            if r:
-                return r
-        r = fs_filter.transform_descendant_piece_designators()
-        if r:
-            return r
+        for node in fs_filter.node.children:
+            children.append(FSNode(node))
+            transformation = node.transform_piece_designators(children[-1])
+            if transformation:
+                return transformation
+        transformation = fs_filter.transform_descendant_piece_designators()
+        if transformation:
+            return transformation
+        return None
 
     def expand_child_piece_designators(self):
         """Expand piece designators in child nodes.
@@ -70,24 +71,47 @@ class CQLNode(Node):
         and cache for optimizing index access.
 
         """
-        for n in self.children:
-            n.expand_child_piece_designators()
+        for node in self.children:
+            node.expand_child_piece_designators()
         if self.leaf:
             if self.tokendef is Token.PIECE_DESIGNATOR:
-                pd = PieceDesignator(self.leaf)
-                pd.parse()
-                pd.expand_piece_designator()
-                self.data = pd
+                piece_designator = PieceDesignator(self.leaf)
+                piece_designator.parse()
+                piece_designator.expand_piece_designator()
+                self.data = piece_designator
+
+    # Beginning of attempt to generalize self.data to instantiate set filter.
+    # Deal with ray filter in addition to piece designator.
+    def expand_set_filters(self):
+        """Expand set filters in child nodes.
+
+        Expanded piece designators are made available in FSNode.designator_set,
+        and cache for optimizing index access.
+
+        """
+        for node in self.children:
+            node.expand_set_filters()
+        if self.leaf:
+            if self.tokendef is Token.PIECE_DESIGNATOR:
+                piece_designator = PieceDesignator(self.leaf)
+                piece_designator.parse()
+                piece_designator.expand_piece_designator()
+                self.data = piece_designator
+            return
+        if self.tokendef is Token.RAY:
+            self.data = RayFilter(self)
 
     def get_shift_limits(self, ranklimits=None, filelimits=None):
+        """Set rank and file shift limits."""
         if self.tokendef is Token.PIECE_DESIGNATOR:
             data = PieceDesignator(self.leaf)
             data.parse()
             data.get_shift_limits(ranklimits, filelimits)
-        for c in self.children:
-            c.get_shift_limits(ranklimits=ranklimits, filelimits=filelimits)
+        for node in self.children:
+            node.get_shift_limits(ranklimits=ranklimits, filelimits=filelimits)
 
     def shift(self, shiftfiles, shiftranks):
+        """Shift shiftfiles and shiftranks for pieces referenced."""
         if self.tokendef is Token.PIECE_DESIGNATOR:
             data = PieceDesignator(self.leaf)
             data.parse()
@@ -100,10 +124,11 @@ class CQLNode(Node):
             if data.is_compound_pieces():
                 pieces = pieces.join(("[", "]"))
             self.leaf = pieces + squares
-        for c in self.children:
-            c.shift(shiftfiles, shiftranks)
+        for node in self.children:
+            node.shift(shiftfiles, shiftranks)
 
     def rotate(self, rotation):
+        """Rotate rotation for pieces referenced."""
         if self.tokendef is Token.PIECE_DESIGNATOR:
             data = PieceDesignator(self.leaf)
             data.parse()
@@ -116,10 +141,11 @@ class CQLNode(Node):
             if data.is_compound_pieces():
                 pieces = pieces.join(("[", "]"))
             self.leaf = pieces + squares
-        for c in self.children:
-            c.rotate(rotation)
+        for node in self.children:
+            node.rotate(rotation)
 
     def reflect_horizontal(self):
+        """Reflect ranks for pieces referenced."""
         if self.tokendef is Token.PIECE_DESIGNATOR:
             data = PieceDesignator(self.leaf)
             data.parse()
@@ -137,10 +163,11 @@ class CQLNode(Node):
             if data.is_compound_pieces():
                 pieces = pieces.join(("[", "]"))
             self.leaf = pieces + squares
-        for c in self.children:
-            c.reflect_horizontal()
+        for node in self.children:
+            node.reflect_horizontal()
 
     def reflect_vertical(self):
+        """Reflect files for pieces referenced."""
         if self.tokendef is Token.PIECE_DESIGNATOR:
             data = PieceDesignator(self.leaf)
             data.parse()
@@ -158,17 +185,18 @@ class CQLNode(Node):
             if data.is_compound_pieces():
                 pieces = pieces.join(("[", "]"))
             self.leaf = pieces + squares
-        for c in self.children:
-            c.reflect_vertical()
+        for node in self.children:
+            node.reflect_vertical()
 
     def rotate_and_reflect_horizontal(self):
+        """Rotate 90 and reflect ranks for pieces referenced."""
         if self.tokendef is Token.PIECE_DESIGNATOR:
             data = PieceDesignator(self.leaf)
             data.parse()
             squares = _normalize_rotated_squares(
                 "".join(
                     [
-                        FSNode._ROTATE_90_REFLECT_HORIZONTAL.get(s, s)
+                        FSNode.ROTATE_90_REFLECT_HORIZONTAL.get(s, s)
                         for s in data.get_squares()
                     ]
                 )
@@ -179,17 +207,18 @@ class CQLNode(Node):
             if data.is_compound_pieces():
                 pieces = pieces.join(("[", "]"))
             self.leaf = pieces + squares
-        for c in self.children:
-            c.rotate_and_reflect_horizontal()
+        for node in self.children:
+            node.rotate_and_reflect_horizontal()
 
     def rotate_and_reflect_vertical(self):
+        """Rotate 90 and reflect files for pieces referenced."""
         if self.tokendef is Token.PIECE_DESIGNATOR:
             data = PieceDesignator(self.leaf)
             data.parse()
             squares = _normalize_rotated_squares(
                 "".join(
                     [
-                        FSNode._ROTATE_90_REFLECT_VERTICAL.get(s, s)
+                        FSNode.ROTATE_90_REFLECT_VERTICAL.get(s, s)
                         for s in data.get_squares()
                     ]
                 )
@@ -200,10 +229,11 @@ class CQLNode(Node):
             if data.is_compound_pieces():
                 pieces = pieces.join(("[", "]"))
             self.leaf = pieces + squares
-        for c in self.children:
-            c.rotate_and_reflect_vertical()
+        for node in self.children:
+            node.rotate_and_reflect_vertical()
 
     def flip_color(self):
+        """Flip the colour of pieces referenced."""
         if self.tokendef is Token.PIECE_DESIGNATOR:
             data = PieceDesignator(self.leaf)
             data.parse()
@@ -229,10 +259,11 @@ class CQLNode(Node):
         elif self.name in FSNode.FLIP_COLOR_FILTER:
             self.name = FSNode.FLIP_COLOR_FILTER[self.name]
             return
-        for c in self.children:
-            c.flip_color()
+        for node in self.children:
+            node.flip_color()
 
     def __deepcopy__(self, memo):
+        """Return a deepcopy of memo."""
         newcopy = super().__deepcopy__(memo)
         newcopy.data = None
         newcopy.where = None
@@ -242,51 +273,48 @@ class CQLNode(Node):
 class FSNode:
     """Scaffolding to evaluate CQLNodes created by the cql package."""
 
-    INITIAL_RANK_LIMITS = RANK_NAMES[-1], RANK_NAMES[0]
+    INITIAL_RANK_LIMITS = CQL_RANK_NAMES[-1], CQL_RANK_NAMES[0]
     INITIAL_FILE_LIMITS = FILE_NAMES[-1], FILE_NAMES[0]
 
-    ROTATE_90 = {
-        x: y
-        for x, y in zip(
-            RANK_NAMES + FILE_NAMES,
+    ROTATE_90 = dict(
+        zip(
+            CQL_RANK_NAMES + FILE_NAMES,
             (
                 "".join(z for z in reversed(FILE_NAMES))
-                + "".join(z for z in RANK_NAMES)
+                + "".join(z for z in CQL_RANK_NAMES)
             ),
         )
-    }
+    )
 
     # This comprehension construct did not work at Python3.6.1 at this place.
-    # ROTATE_180 = {x:ROTATE_90[ROTATE_90[x]] for x in RANK_NAMES + FILE_NAMES}
+    # ROTATE_180 = {x:ROTATE_90[ROTATE_90[x]]
+    # for x in CQL_RANK_NAMES + FILE_NAMES}
 
     ROTATE_180 = {}
-    for x in RANK_NAMES + FILE_NAMES:
+    for x in CQL_RANK_NAMES + FILE_NAMES:
         ROTATE_180[x] = ROTATE_90[ROTATE_90[x]]
     ROTATE_270 = {}
-    for x in RANK_NAMES + FILE_NAMES:
+    for x in CQL_RANK_NAMES + FILE_NAMES:
         ROTATE_270[x] = ROTATE_90[ROTATE_180[x]]
-    REFLECT_HORIZONTAL = {
-        x: y
-        for x, y in zip(RANK_NAMES, "".join(z for z in reversed(RANK_NAMES)))
-    }
-    REFLECT_VERTICAL = {
-        x: y
-        for x, y in zip(FILE_NAMES, "".join(z for z in reversed(FILE_NAMES)))
-    }
+    REFLECT_HORIZONTAL = dict(
+        zip(CQL_RANK_NAMES, "".join(z for z in reversed(CQL_RANK_NAMES)))
+    )
+    REFLECT_VERTICAL = dict(
+        zip(FILE_NAMES, "".join(z for z in reversed(FILE_NAMES)))
+    )
 
     # These rotate-reflect combinations are not defined by CQL but are used to
     # generate the diagonal reflections needed to complete the flip transform.
-    _ROTATE_90_REFLECT_HORIZONTAL = {}
-    _ROTATE_90_REFLECT_VERTICAL = {}
-    for x in RANK_NAMES + FILE_NAMES:
+    ROTATE_90_REFLECT_HORIZONTAL = {}
+    ROTATE_90_REFLECT_VERTICAL = {}
+    for x in CQL_RANK_NAMES + FILE_NAMES:
         y = ROTATE_90[x]
-        _ROTATE_90_REFLECT_HORIZONTAL[x] = REFLECT_HORIZONTAL.get(y, y)
-        _ROTATE_90_REFLECT_VERTICAL[x] = REFLECT_VERTICAL.get(y, y)
+        ROTATE_90_REFLECT_HORIZONTAL[x] = REFLECT_HORIZONTAL.get(y, y)
+        ROTATE_90_REFLECT_VERTICAL[x] = REFLECT_VERTICAL.get(y, y)
     del x, y
 
-    FLIP_COLOR_PIECE = {
-        x: y
-        for x, y in zip(
+    FLIP_COLOR_PIECE = dict(
+        zip(
             PIECE_NAMES,
             "".join(
                 (
@@ -298,7 +326,7 @@ class FSNode:
                 )
             ),
         )
-    }
+    )
     FLIP_COLOR_TOMOVE = {
         Token.WTM.name: Token.BTM.name,
         Token.BTM.name: Token.WTM.name,
@@ -309,6 +337,7 @@ class FSNode:
     }
 
     def __init__(self, node):
+        """Note node and initialize child nodes to empty list."""
         self.node = node
         self.children = []
 
@@ -436,10 +465,13 @@ class FSNode:
         ≡ K
 
         """
-        for c in self.children:
-            r = self._transform.get(c.node.tokendef, lambda s: None)(c)
-            if r:
-                return r
+        for node in self.children:
+            transformed = self._transform.get(
+                node.node.tokendef, lambda s: None
+            )(node)
+            if transformed:
+                return transformed
+        return None
 
     def _flip(self):
         ranklow, rankhigh, filelow, filehigh = self._get_transform_limits()
@@ -449,12 +481,12 @@ class FSNode:
         ) == FSNode.INITIAL_FILE_LIMITS:
             return
         transforms = []
-        for r in (
+        for transformed in (
             FSNode.ROTATE_90,
             FSNode.ROTATE_180,
             FSNode.ROTATE_270,
         ):
-            transforms.extend(self._generate_rotated_filters(r))
+            transforms.extend(self._generate_rotated_filters(transformed))
         transforms.extend(self._generate_vertical_reflection_filters())
         transforms.extend(self._generate_horizontal_reflection_filters())
         transforms.extend(
@@ -463,8 +495,8 @@ class FSNode:
         transforms.extend(
             self._generate_rotate_90_horizontal_reflection_filters()
         )
-        for t in transforms:
-            self.node.children.append(t.node)
+        for tnode in transforms:
+            self.node.children.append(tnode.node)
 
     def _fliphorizontal(self):
         ranklow, rankhigh, filelow, filehigh = self._get_transform_limits()
@@ -474,8 +506,8 @@ class FSNode:
         ) == FSNode.INITIAL_FILE_LIMITS:
             return
         transforms = self._generate_horizontal_reflection_filters()
-        for t in transforms:
-            self.node.children.append(t.node)
+        for tnode in transforms:
+            self.node.children.append(tnode.node)
 
     def _flipvertical(self):
         ranklow, rankhigh, filelow, filehigh = self._get_transform_limits()
@@ -485,8 +517,8 @@ class FSNode:
         ) == FSNode.INITIAL_FILE_LIMITS:
             return
         transforms = self._generate_vertical_reflection_filters()
-        for t in transforms:
-            self.node.children.append(t.node)
+        for tnode in transforms:
+            self.node.children.append(tnode.node)
 
     def _rotate90(self):
         ranklow, rankhigh, filelow, filehigh = self._get_transform_limits()
@@ -496,14 +528,14 @@ class FSNode:
         ) == FSNode.INITIAL_FILE_LIMITS:
             return
         transforms = []
-        for r in (
+        for transformed in (
             FSNode.ROTATE_90,
             FSNode.ROTATE_180,
             FSNode.ROTATE_270,
         ):
-            transforms.extend(self._generate_rotated_filters(r))
-        for t in transforms:
-            self.node.children.append(t.node)
+            transforms.extend(self._generate_rotated_filters(transformed))
+        for tnode in transforms:
+            self.node.children.append(tnode.node)
 
     def _rotate45(self):
         ranklow, rankhigh, filelow, filehigh = self._get_transform_limits()
@@ -520,8 +552,8 @@ class FSNode:
         Some points from http://www.gadycosteff.com/cql/doc/transform.html for
         cql5.0 are:
 
-        The flipcolor transform applied to filter is the 'or' of filter with the
-        new filter formed from the filter as follows:
+        The flipcolor transform applied to filter is the 'or' of filter with
+        the new filter formed from the filter as follows:
 
             the colors of any piece designators in filter are changed;
             'wtm' is changed to 'btm' and vice versa;
@@ -533,8 +565,8 @@ class FSNode:
 
         """
         transforms = self._generate_flipped_color_filters()
-        for t in transforms:
-            self.node.children.append(t.node)
+        for tnode in transforms:
+            self.node.children.append(tnode.node)
 
     def _shift(self):
         ranklow, rankhigh, filelow, filehigh = self._get_transform_limits()
@@ -551,43 +583,51 @@ class FSNode:
             return
         sourcefiles = list(FILE_NAMES)
         fileshifts = []
-        i = sourcefiles.index(filelow) + 8 - sourcefiles.index(filehigh)
-        for j in range(sourcefiles.index(filelow)):
+        limit_range = (
+            sourcefiles.index(filelow) + 8 - sourcefiles.index(filehigh)
+        )
+        for count in range(sourcefiles.index(filelow)):
             sourcefiles.append(sourcefiles.pop(0))
-        for j in range(i):
-            fileshifts.append({x: y for x, y in zip(sourcefiles, FILE_NAMES)})
+        for count in range(limit_range):
+            fileshifts.append(dict(zip(sourcefiles, FILE_NAMES)))
             sourcefiles.insert(0, sourcefiles.pop())
-        sourceranks = list(RANK_NAMES)
+        # pylint message unused-variable.
+        # Find a way of doing without count in this method's loops.
+        del count
+        sourceranks = list(CQL_RANK_NAMES)
         rankrange = (
             sourceranks.index(ranklow) + 8 - sourceranks.index(rankhigh)
         )
-        for j in range(sourceranks.index(ranklow)):
+        for count in range(sourceranks.index(ranklow)):
             sourceranks.append(sourceranks.pop(0))
         transforms = []
-        for j in range(rankrange):
-            rankshifts = {x: y for x, y in zip(sourceranks, RANK_NAMES)}
-            for fs in fileshifts:
-                if fs[filelow] != filelow or rankshifts[ranklow] != ranklow:
+        for count in range(rankrange):
+            rankshifts = dict(zip(sourceranks, CQL_RANK_NAMES))
+            for fshift in fileshifts:
+                if (
+                    fshift[filelow] != filelow
+                    or rankshifts[ranklow] != ranklow
+                ):
                     transforms.extend(
-                        self._generate_shifted_filters(fs, rankshifts)
+                        self._generate_shifted_filters(fshift, rankshifts)
                     )
             sourceranks.insert(0, sourceranks.pop())
-        for t in transforms:
-            self.node.children.append(t.node)
+        for tnode in transforms:
+            self.node.children.append(tnode.node)
 
     def _shiftvertical(self):
         ranklimits = list(FSNode.INITIAL_RANK_LIMITS)
         self.node.get_shift_limits(ranklimits=ranklimits)
         if tuple(ranklimits) == FSNode.INITIAL_RANK_LIMITS:
             return
-        self._shift_one_direction(ranklimits, RANK_NAMES, FILE_NAMES)
+        self._shift_one_direction(ranklimits, CQL_RANK_NAMES, FILE_NAMES)
 
     def _shifthorizontal(self):
         filelimits = list(FSNode.INITIAL_FILE_LIMITS)
         self.node.get_shift_limits(filelimits=filelimits)
         if tuple(filelimits) == FSNode.INITIAL_FILE_LIMITS:
             return
-        self._shift_one_direction(filelimits, FILE_NAMES, RANK_NAMES)
+        self._shift_one_direction(filelimits, FILE_NAMES, CQL_RANK_NAMES)
 
     _transform = {
         Token.FLIP: _flip,
@@ -602,10 +642,10 @@ class FSNode:
     }
 
     def _get_transform_limits(self):
-        rl = list(FSNode.INITIAL_RANK_LIMITS)
-        fl = list(FSNode.INITIAL_FILE_LIMITS)
-        self.node.get_shift_limits(ranklimits=rl, filelimits=fl)
-        return rl[0], rl[1], fl[0], fl[1]
+        ranklimit = list(FSNode.INITIAL_RANK_LIMITS)
+        filelimit = list(FSNode.INITIAL_FILE_LIMITS)
+        self.node.get_shift_limits(ranklimits=ranklimit, filelimits=filelimit)
+        return ranklimit[0], ranklimit[1], filelimit[0], filelimit[1]
 
     def _shift_one_direction(self, limits, shiftsource, staticsource):
         """Extend children with one-direction transformed filters.
@@ -620,122 +660,133 @@ class FSNode:
         """
         source = list(shiftsource)
         shifts = []
-        i = source.index(limits[0]) + 8 - source.index(limits[1])
-        for j in range(source.index(limits[0])):
+        limit_range = source.index(limits[0]) + 8 - source.index(limits[1])
+        for count in range(source.index(limits[0])):
             source.append(source.pop(0))
-        for j in range(i):
-            shifts.append({x: y for x, y in zip(source, shiftsource)})
+        for count in range(limit_range):
+            shifts.append(dict(zip(source, shiftsource)))
             source.insert(0, source.pop())
-        static = {x: y for x, y in zip(staticsource, staticsource)}
+        # pylint message unused-variable.
+        # Find a way of doing without count in this method's loops.
+        del count
+        static = dict(zip(staticsource, staticsource))
         transforms = []
-        for fs in shifts:
-            if fs[limits[0]] != limits[0]:
-                transforms.extend(self._generate_shifted_filters(fs, static))
-        for t in transforms:
-            self.node.children.append(t.node)
+        for tshift in shifts:
+            if tshift[limits[0]] != limits[0]:
+                transforms.extend(
+                    self._generate_shifted_filters(tshift, static)
+                )
+        for tnode in transforms:
+            self.node.children.append(tnode.node)
 
     def _generate_shifted_filters(self, shiftfiles, shiftranks):
         transforms = []
-        for c in self.children:
-            transforms.append(copy.deepcopy(c))
+        for node in self.children:
+            transforms.append(copy.deepcopy(node))
             transforms[-1].node.shift(shiftfiles, shiftranks)
         return transforms
 
     def _generate_rotated_filters(self, rotation):
         transforms = []
-        for c in self.children:
-            transforms.append(copy.deepcopy(c))
+        for node in self.children:
+            transforms.append(copy.deepcopy(node))
             transforms[-1].node.rotate(rotation)
         return transforms
 
     def _generate_horizontal_reflection_filters(self):
         transforms = []
-        for c in self.children:
-            transforms.append(copy.deepcopy(c))
+        for node in self.children:
+            transforms.append(copy.deepcopy(node))
             transforms[-1].node.reflect_horizontal()
         return transforms
 
     def _generate_vertical_reflection_filters(self):
         transforms = []
-        for c in self.children:
-            transforms.append(copy.deepcopy(c))
+        for node in self.children:
+            transforms.append(copy.deepcopy(node))
             transforms[-1].node.reflect_vertical()
         return transforms
 
     def _generate_rotate_90_horizontal_reflection_filters(self):
         transforms = []
-        for c in self.children:
-            transforms.append(copy.deepcopy(c))
+        for node in self.children:
+            transforms.append(copy.deepcopy(node))
             transforms[-1].node.rotate_and_reflect_horizontal()
         return transforms
 
     def _generate_rotate_90_vertical_reflection_filters(self):
         transforms = []
-        for c in self.children:
-            transforms.append(copy.deepcopy(c))
+        for node in self.children:
+            transforms.append(copy.deepcopy(node))
             transforms[-1].node.rotate_and_reflect_vertical()
         return transforms
 
     def _generate_flipped_color_filters(self):
         transforms = []
-        for c in self.children:
-            transforms.append(copy.deepcopy(c))
+        for node in self.children:
+            transforms.append(copy.deepcopy(node))
             transforms[-1].node.flip_color()
         return transforms
 
-    def _trace(self, level=0):
-        if self.leaf:
-            print(level, self.leaf._token)
-        for c in self.children:
-            print(level, self.node.name, id(self.node))
-            c._trace(level=level + 1)
-
 
 def _normalize_rotated_squares(squares):
-    ns = []
-    for s in squares.split(SQUARE_DESIGNATOR_SEPARATOR):
-        s = list(s)
-        if len(s) == 2:
-            if s[0] in RANK_NAMES:
-                s[0], s[1] = s[1], s[0]
-        elif len(s) == 6:
-            if s[0] > s[2]:
-                s[0], s[2] = s[2], s[0]
-            if s[3] > s[5]:
-                s[3], s[5] = s[5], s[3]
-            if s[0] in RANK_NAMES:
-                s[0], s[2], s[3], s[5] = s[3], s[5], s[0], s[2]
-        elif s[1] == RANGE_SEPARATOR:
-            if s[0] > s[2]:
-                s[0], s[2] = s[2], s[0]
-            if s[0] in RANK_NAMES:
-                s.insert(0, s.pop())
-        elif s[2] == RANGE_SEPARATOR:
-            if s[1] > s[3]:
-                s[1], s[3] = s[3], s[1]
-            if s[0] in RANK_NAMES:
-                s.append(s.pop(0))
-        ns.append("".join(s))
-    return SQUARE_DESIGNATOR_SEPARATOR.join(ns)
+    normalized_squares = []
+    for designator in squares.split(SQUARE_DESIGNATOR_SEPARATOR):
+        square = list(designator)
+        if len(square) == 2:
+            if square[0] in CQL_RANK_NAMES:
+                square[0], square[1] = square[1], square[0]
+        elif len(square) == 6:
+            if square[0] > square[2]:
+                square[0], square[2] = square[2], square[0]
+            if square[3] > square[5]:
+                square[3], square[5] = square[5], square[3]
+            if square[0] in CQL_RANK_NAMES:
+                square[0], square[2], square[3], square[5] = (
+                    square[3],
+                    square[5],
+                    square[0],
+                    square[2],
+                )
+        elif square[1] == RANGE_SEPARATOR:
+            if square[0] > square[2]:
+                square[0], square[2] = square[2], square[0]
+            if square[0] in CQL_RANK_NAMES:
+                square.insert(0, square.pop())
+        elif square[2] == RANGE_SEPARATOR:
+            if square[1] > square[3]:
+                square[1], square[3] = square[3], square[1]
+            if square[0] in CQL_RANK_NAMES:
+                square.append(square.pop(0))
+        normalized_squares.append("".join(square))
+    return SQUARE_DESIGNATOR_SEPARATOR.join(normalized_squares)
 
 
 def _normalize_horizontally_reflected_squares(squares):
-    ns = []
-    for s in squares.split(SQUARE_DESIGNATOR_SEPARATOR):
-        if len(s) == 6 or len(s) == 4 and s[2] == RANGE_SEPARATOR:
-            s = list(s)
-            s[-3], s[-1] = s[-1], s[-3]
-            s = "".join(s)
-        ns.append("".join(s))
-    return SQUARE_DESIGNATOR_SEPARATOR.join(ns)
+    normalized_squares = []
+    for square in squares.split(SQUARE_DESIGNATOR_SEPARATOR):
+        if (
+            len(square) == 6
+            or len(square) == 4
+            and square[2] == RANGE_SEPARATOR
+        ):
+            square = list(square)
+            square[-3], square[-1] = square[-1], square[-3]
+            square = "".join(square)
+        normalized_squares.append("".join(square))
+    return SQUARE_DESIGNATOR_SEPARATOR.join(normalized_squares)
 
 
 def _normalize_vertically_reflected_squares(squares):
-    ns = []
-    for s in squares.split(SQUARE_DESIGNATOR_SEPARATOR):
-        if len(s) == 6 or len(s) == 4 and s[1] == RANGE_SEPARATOR:
-            s = list(s)
-            s[0], s[2] = s[2], s[0]
-            s = "".join(s)
-        ns.append("".join(s))
-    return SQUARE_DESIGNATOR_SEPARATOR.join(ns)
+    normalized_squares = []
+    for square in squares.split(SQUARE_DESIGNATOR_SEPARATOR):
+        if (
+            len(square) == 6
+            or len(square) == 4
+            and square[1] == RANGE_SEPARATOR
+        ):
+            square = list(square)
+            square[0], square[2] = square[2], square[0]
+            square = "".join(square)
+        normalized_squares.append("".join(square))
+    return SQUARE_DESIGNATOR_SEPARATOR.join(normalized_squares)
