@@ -25,7 +25,7 @@ When CQL has finished trying to match all the positions in the game against its
 filters, then if any of the positions matched, CQL will output the game to the
 output file. The output file can be specified either by default (in which case
 its name is the name of the CQL file with -out appended); or as a parameter in
-to the cql arguments in the CQL file itself; or on the command line. 
+to the cql arguments in the CQL file itself; or on the command line.
 
 
 The earlier partial position scheme implemented a sequence of piece designator
@@ -38,7 +38,7 @@ black piece or empty square matches.
 
 """
 
-from chessql.core.statement import Statement
+from chessql.core.statement import Statement, ErrorInformation
 
 # from chessql.core.constants import PIECE_DESIGNATOR_FILTER
 # from chessql.core.piecedesignator import PieceDesignator
@@ -50,7 +50,7 @@ _ROTATE45_VALIDATION_TABLE = str.maketrans("12345678", "xxxxxxxx")
 
 
 class CQLStatementError(Exception):
-    pass
+    """Exception class for cqlstatement module."""
 
 
 class CQLStatement(Statement):
@@ -63,7 +63,7 @@ class CQLStatement(Statement):
     create_node = CQLNode
 
     def __init__(self):
-        """ """
+        """Delegate then initialize description and database name."""
         # Error handling is slightly different to .querystatement module.
         # The error information object is held directly here while it is held
         # in the Where instance used to calculate the query there.
@@ -72,7 +72,7 @@ class CQLStatement(Statement):
         self._description_string = ""
 
         # Not sure this is needed or wanted.
-        # See datasource argument to get_games_matching_filters().
+        # See datasource argument to _get_games_matching_filters().
         # dbset not used until a QueryStatement instance evaluates query.
         # self._dbset = None
 
@@ -89,6 +89,7 @@ class CQLStatement(Statement):
 
     @property
     def dbset(self):
+        """Return database filename."""
         return self._dbset
 
     @dbset.setter
@@ -165,20 +166,22 @@ class CQLStatement(Statement):
         # valid Chess QL statement.
         if self.cql_filters is None:
             return
-        r = self.cql_filters.transform_piece_designators(
+        transformation = self.cql_filters.transform_piece_designators(
             FSNode(self.cql_filters)
         )
-        if r:
-            self.cql_error = r
+        if transformation:
+            self.cql_error = transformation
         return
 
     def _rotate45_specific_squares(self, filter_, rotate45stack):
         if filter_.name == "rotate45":
             rotate45stack.append(None)
-        for n in filter_.children:
-            if rotate45stack and n.name == "piecedesignator":
-                # if {c for c in n.leaf}.intersection('12345678'))
-                if n.leaf != n.leaf.translate(_ROTATE45_VALIDATION_TABLE):
+        for node in filter_.children:
+            if rotate45stack and node.name == "piecedesignator":
+                # if {c for c in node.leaf}.intersection('12345678'))
+                if node.leaf != node.leaf.translate(
+                    _ROTATE45_VALIDATION_TABLE
+                ):
                     self._error_information = ErrorInformation(
                         self._statement_string.strip()
                     )
@@ -186,7 +189,7 @@ class CQLStatement(Statement):
                         "rotate45 on specific squares"
                     )
                     return self._error_information
-            r45ss = self._rotate45_specific_squares(n, rotate45stack)
+            r45ss = self._rotate45_specific_squares(node, rotate45stack)
             if r45ss:
                 return r45ss
         if filter_.name == "rotate45":
