@@ -13,23 +13,23 @@ See www.dptoolkit.com for details of DPT
 """
 
 import os
-import bz2
+from io import StringIO
+import multiprocessing  # Removed later by 'del multiprocessing'.
+
 import tkinter
 import tkinter.messagebox
-from io import StringIO
 
-from dptdb.dptapi import (
-    FILEDISP_OLD,
-    FISTAT_DEFERRED_UPDATES,
-    APIContextSpecification,
-)
+# pylint will always give import-error message on non-Microsoft Windows
+# systems.
+# Wine counts as a Microsft Windows system.
+# It is reasonable to not install 'dptdb.dptapi'.
+# The importlib module is used to import chessdptdu if needed.
+from dptdb.dptapi import FISTAT_DEFERRED_UPDATES
 
 from solentware_base import dptdu_database
 from solentware_base.core.constants import (
     FILEDESC,
     BRECPPG,
-    BSIZE,
-    DSIZE,
     TABLE_B_SIZE,
 )
 
@@ -40,6 +40,7 @@ from ..core.filespec import (
     POSITIONS_PER_GAME,
 )
 from ..core.chessrecord import ChessDBrecordGameImport
+from ..shared.archivedu import Archivedu
 
 # Current practical way to determine if running on Wine, taking advantage of
 # a problem found in ..core.uci which prevents UCI chess engines being used to
@@ -57,27 +58,24 @@ from ..core.chessrecord import ChessDBrecordGameImport
 # engines.
 # DB_SEGMENT_SIZE has no effect on processing apart from report points.
 DB_SEGMENT_SIZE = 65536
-import multiprocessing
-
 try:
     multiprocessing.Queue()
     _DEFERRED_UPDATE_POINTS = (DB_SEGMENT_SIZE - 1,)
 except OSError:
     _DEFERRED_UPDATE_POINTS = tuple(
-        [
-            i
-            for i in range(
-                DB_SEGMENT_SIZE // 8 - 1, DB_SEGMENT_SIZE, DB_SEGMENT_SIZE // 8
-            )
-        ]
+        i
+        for i in range(
+            DB_SEGMENT_SIZE // 8 - 1, DB_SEGMENT_SIZE, DB_SEGMENT_SIZE // 8
+        )
     )
 del multiprocessing
 del DB_SEGMENT_SIZE
+
 CHUNKGAMES = 6144
 
 
 class ChessdptduError(Exception):
-    pass
+    """Exception class for chessdptdu module."""
 
 
 def chess_dptdu(
@@ -90,21 +88,20 @@ def chess_dptdu(
     cdb = ChessDatabase(dbpath, allowcreate=True)
     importer = ChessDBrecordGameImport()
     cdb.open_database(files=file_records)
-    for pp in pgnpaths:
-        s = open(pp, "r", encoding="iso-8859-1")
-        importer.import_pgn(cdb, s, pp, reporter=reporter)
-        s.close()
+    for pgnfile in pgnpaths:
+        with open(pgnfile, "r", encoding="iso-8859-1") as source:
+            importer.import_pgn(cdb, source, pgnfile, reporter=reporter)
     reporter("Finishing import: please wait.")
     reporter("", timestamp=False)
     cdb.close_database_contexts(files=file_records)
     cdb.open_database_contexts(files=file_records)
     status = True
-    for f in (
+    for file in (
         cdb.specification.keys() if file_records is None else file_records
     ):
         if (
             FISTAT_DEFERRED_UPDATES
-            != cdb.table[f].get_file_parameters(cdb.dbenv)["FISTAT"][0]
+            != cdb.table[file].get_file_parameters(cdb.dbenv)["FISTAT"][0]
         ):
             status = False
     cdb.close_database_contexts()
@@ -116,72 +113,66 @@ def chess_dptdu_chunks(
 ):
     """Open database, import games in fixed chunks and close database."""
 
-    def write_chunk(sample=None):
+    def write_chunk(pgnpath, sample=None):
         cdb.open_database(files=sample)
 
         # chess_dptdu_chunks does the reporting so do not pass reporter to
         # import_pgn, but the name of the source file is mandantory.
-        importer.import_pgn(cdb, StringIO("".join(games)), pp)
+        importer.import_pgn(cdb, StringIO("".join(games)), pgnpath)
 
         cdb.close_database_contexts()
         games[:] = []
 
     cdb = ChessDatabase(dbpath, allowcreate=True)
     importer = ChessDBrecordGameImport()
-    chunks = []
     games = []
     gamelines = []
     newgamestring = '[Event "'
     records = file_records
-    for pp in pgnpaths:
-        cdb._text_file_size = os.path.getsize(pp)
-        inp = open(pp, "r", encoding="iso-8859-1")
-        line = inp.readline()
-        reporter("Extracting games from " + pp)
-        count = 0
-        while line:
-            if line.startswith(newgamestring):
-                games.append("".join(gamelines))
-                gamelines = []
-                if len(games) >= CHUNKGAMES:
-                    records = write_chunk(sample=records)
-                    count += 1
-                    reporter(
-                        " ".join(
-                            (
-                                "Chunk",
-                                str(count),
-                                "written, total games added:",
-                                str(CHUNKGAMES * count),
+    for pgnfile in pgnpaths:
+        with open(pgnfile, "r", encoding="iso-8859-1") as inp:
+            line = inp.readline()
+            reporter("Extracting games from " + pgnfile)
+            count = 0
+            while line:
+                if line.startswith(newgamestring):
+                    games.append("".join(gamelines))
+                    gamelines = []
+                    if len(games) >= CHUNKGAMES:
+                        write_chunk(pgnfile, sample=records)
+                        count += 1
+                        reporter(
+                            " ".join(
+                                (
+                                    "Chunk",
+                                    str(count),
+                                    "written, total games added:",
+                                    str(CHUNKGAMES * count),
+                                )
                             )
                         )
-                    )
-            gamelines.append(line)
-            line = inp.readline()
-        inp.close()
+                gamelines.append(line)
+                line = inp.readline()
         if gamelines:
             games.append("".join(gamelines))
-            records = write_chunk(sample=records)
-        reporter("Extraction from " + pp + " done")
+            write_chunk(pgnfile, sample=records)
+        reporter("Extraction from " + pgnfile + " done")
         reporter("", timestamp=False)
     reporter("Finishing import: please wait.")
     reporter("", timestamp=False)
     cdb.open_database_contexts(files=file_records)
     status = True
-    for f in file_records:
+    for file in file_records:
         if (
             FISTAT_DEFERRED_UPDATES
-            != cdb.get_database_instance(f, None).get_file_parameters(
-                cdb.dbenv
-            )["FISTAT"][0]
+            != cdb.table[file].get_file_parameters(cdb.dbenv)["FISTAT"][0]
         ):
             status = False
     cdb.close_database_contexts()
     return status
 
 
-class ChessDatabaseDeferred:
-
+class ChessDatabaseDeferred(dptdu_database.Database):
     """Provide deferred update methods for a database of games of chess.
 
     Subclasses must include a subclass of dptbase.Database as a superclass.
@@ -209,30 +200,26 @@ class ChessDatabaseDeferred:
         """
         ddnames = FileSpec(**kargs)
         # Deferred update for games file only
-        for dd in list(ddnames.keys()):
-            if dd != GAMES_FILE_DEF:
-                del ddnames[dd]
+        for ddname in list(ddnames.keys()):
+            if ddname != GAMES_FILE_DEF:
+                del ddnames[ddname]
 
         if not kargs.get("allowcreate", False):
             try:
-                for dd in ddnames:
-                    if FILEDESC in ddnames[dd]:
-                        del ddnames[dd][FILEDESC]
-            except:
+                for ddname in ddnames:
+                    if FILEDESC in ddnames[ddname]:
+                        del ddnames[ddname][FILEDESC]
+            except Exception as error:
                 if __name__ == "__main__":
                     raise
-                else:
-                    raise ChessdptduError("DPT description invalid")
+                raise ChessdptduError("DPT description invalid") from error
 
         try:
-            super(ChessDatabaseDeferred, self).__init__(
-                ddnames, databasefolder, **kargs
-            )
-        except ChessdptduError:
+            super().__init__(ddnames, databasefolder, **kargs)
+        except ChessdptduError as error:
             if __name__ == "__main__":
                 raise
-            else:
-                raise ChessdptduError("DPT description invalid")
+            raise ChessdptduError("DPT description invalid") from error
 
         # Retain import estimates for increase size by button actions
         self._import_estimates = None
@@ -241,14 +228,19 @@ class ChessDatabaseDeferred:
         self._reporter = None
 
     def open_database(self, files=None):
-        """Raise ChessdptduError if any opened file is mot in DEFERRED_UPDATE
-        mode.
+        """Delegate then raise ChessdptduError if database is inconsistent.
+
+        Normally return None with the database open.
+
+        Close the database and raise ChessdptduError exception if the
+        database FISTAT parameter is not equal FISTAT_DEFERRED_UPDATES.
+
         """
         super().open_database(files=files)
-        vr = self.dbenv.Core().GetViewerResetter()
+        viewer = self.dbenv.Core().GetViewerResetter()
         for dbo in self.table.values():
             if (
-                vr.ViewAsInt("FISTAT", dbo.opencontext)
+                viewer.ViewAsInt("FISTAT", dbo.opencontext)
                 != FISTAT_DEFERRED_UPDATES
             ):
                 break
@@ -261,11 +253,11 @@ class ChessDatabaseDeferred:
         raise ChessdptduError("A file is not in deferred update mode")
 
     def open_context_prepare_import(self):
-        """Open all files normally"""
+        """Open all files normally."""
         super().open_database()
 
     def get_archive_names(self, files=()):
-        """Return specified files and existing operating system files"""
+        """Return specified files and existing operating system files."""
         specs = {f for f in files if f in self.table}
         names = [v.file for k, v in self.table.items() if k in specs]
         exists = [
@@ -275,79 +267,34 @@ class ChessDatabaseDeferred:
         ]
         return (names, exists)
 
-    def get_pages_for_record_counts(self, counts=(0, 0)):
-        """Return Table B and Table D pages needed for record counts"""
+    def _get_pages_for_record_counts(self, counts=(0, 0)):
+        """Return Table B and Table D pages needed for record counts."""
         brecppg = self.table[GAMES_FILE_DEF].filedesc[BRECPPG]
         return (
             counts[0] // brecppg,
             (counts[1] * self.table[GAMES_FILE_DEF].btod_factor) // brecppg,
         )
 
-    def archive(self, flag=None, names=None):
-        """Write a bz2 backup of file containing games.
-
-        Intended to be a backup in case import fails.
-
-        """
-        if names is None:
-            return False
-        if not self.delete_archive(flag=flag, names=names):
-            return
-        if flag:
-            for n in names:
-                c = bz2.BZ2Compressor()
-                archiveguard = ".".join((n, "grd"))
-                archivename = ".".join((n, "bz2"))
-                fi = open(n, "rb")
-                fo = open(archivename, "wb")
-                inp = fi.read(10000000)
-                while inp:
-                    co = c.compress(inp)
-                    if co:
-                        fo.write(co)
-                    inp = fi.read(10000000)
-                co = c.flush()
-                if co:
-                    fo.write(co)
-                fo.close()
-                fi.close()
-                c = open(archiveguard, "wb")
-                c.close()
-        return True
-
-    def delete_archive(self, flag=None, names=None):
-        """Delete a bz2 backup of file containing games."""
-        if names is None:
-            return False
-        if flag:
-            for n in names:
-                archiveguard = ".".join((n, "grd"))
-                archivename = ".".join((n, "bz2"))
-                try:
-                    os.remove(archiveguard)
-                except:
-                    pass
-                try:
-                    os.remove(archivename)
-                except:
-                    pass
-        return True
-
-    def get_database_table_sizes(self, files=None):
+    def _get_database_table_sizes(self, files=None):
         """Return Table B and D size and usage in pages for files."""
         if files is None:
             files = dict()
-        fs = dict()
-        for k, v in self.get_database_parameters(
+        filesize = dict()
+        for key, value in self.get_database_parameters(
             files=list(files.keys())
         ).items():
-            fs[k] = (v["BSIZE"], v["BHIGHPG"], v["DSIZE"], v["DPGSUSED"])
-        fi = self.get_database_increase(files=files)
+            filesize[key] = (
+                value["BSIZE"],
+                value["BHIGHPG"],
+                value["DSIZE"],
+                value["DPGSUSED"],
+            )
+        increase = self.get_database_increase(files=files)
         self.close_database_contexts()
-        return fs, fi
+        return filesize, increase
 
     def add_import_buttons(
-        self, master, try_command_wrapper, try_event_wrapper, widget
+        self, master, try_command_wrapper, try_event_wrapper, bind, widget
     ):
         """Add button actions for DPT to Import dialogue.
 
@@ -361,7 +308,7 @@ class ChessDatabaseDeferred:
             command=try_command_wrapper(self._increase_index, master),
         )
         index.pack(side=tkinter.RIGHT, padx=12)
-        widget.bind("<Alt-x>", try_event_wrapper(self._increase_index))
+        bind(widget, "<Alt-x>", try_event_wrapper(self._increase_index))
         data = tkinter.Button(
             master=master,
             text="Increase Data",
@@ -369,7 +316,7 @@ class ChessDatabaseDeferred:
             command=try_command_wrapper(self._increase_data, master),
         )
         data.pack(side=tkinter.RIGHT, padx=12)
-        widget.bind("<Alt-d>", try_event_wrapper(self._increase_data))
+        bind(widget, "<Alt-d>", try_event_wrapper(self._increase_data))
 
     def _increase_data(self, event=None):
         """Add maximum of current free space and default size to Table B.
@@ -378,21 +325,22 @@ class ChessDatabaseDeferred:
         and keypress,
 
         """
-        self.open_context_normal(files=(GAMES_FILE_DEF,))
+        del event
+        self.open_database_contexts(files=(GAMES_FILE_DEF,))
         increase_done = False
-        for k, v in self.get_database_parameters(
+        for key, value in self.get_database_parameters(
             files=(GAMES_FILE_DEF,)
         ).items():
-            bsize = v["BSIZE"]
-            bused = max(0, v["BHIGHPG"])
-            bneeded = self.get_pages_for_record_counts(
-                self._notional_record_counts[k]
+            bsize = value["BSIZE"]
+            bused = max(0, value["BHIGHPG"])
+            bneeded = self._get_pages_for_record_counts(
+                self._notional_record_counts[key]
             )[0]
             bincrease = min(bneeded * 2, bsize - bused)
             message = "".join(
                 (
                     "The free data size of the ",
-                    k,
+                    key,
                     " file will be increased from ",
                     str(bsize - bused),
                     " pages to ",
@@ -400,7 +348,7 @@ class ChessDatabaseDeferred:
                     " pages.",
                 )
             )
-            if len(self.table[k].get_extents()) % 2 == 0:
+            if len(self.table[key].get_extents()) % 2 == 0:
                 message = "".join(
                     (
                         message,
@@ -419,7 +367,7 @@ class ChessDatabaseDeferred:
                 ),
             ):
                 increase_done = True
-                self.table[k].opencontext.Increase(bincrease, False)
+                self.table[key].opencontext.Increase(bincrease, False)
         if increase_done:
             self._reporter.append_text(
                 " ".join(
@@ -440,21 +388,22 @@ class ChessDatabaseDeferred:
         and keypress,
 
         """
-        self.open_context_normal(files=(GAMES_FILE_DEF,))
+        del event
+        self.open_database_contexts(files=(GAMES_FILE_DEF,))
         increase_done = False
-        for k, v in self.get_database_parameters(
+        for key, value in self.get_database_parameters(
             files=(GAMES_FILE_DEF,)
         ).items():
-            dsize = v["DSIZE"]
-            dused = v["DPGSUSED"]
-            dneeded = self.get_pages_for_record_counts(
-                self._notional_record_counts[k]
+            dsize = value["DSIZE"]
+            dused = value["DPGSUSED"]
+            dneeded = self._get_pages_for_record_counts(
+                self._notional_record_counts[key]
             )[1]
             dincrease = min(dneeded * 2, dsize - dused)
             message = "".join(
                 (
                     "The free index size of the ",
-                    k,
+                    key,
                     " file will be increased from ",
                     str(dsize - dused),
                     " pages to ",
@@ -462,7 +411,7 @@ class ChessDatabaseDeferred:
                     " pages.",
                 )
             )
-            if len(self.table[k].get_extents()) % 2 != 0:
+            if len(self.table[key].get_extents()) % 2 != 0:
                 message = "".join(
                     (
                         message,
@@ -481,7 +430,7 @@ class ChessDatabaseDeferred:
                 ),
             ):
                 increase_done = True
-                self.table[k].opencontext.Increase(dincrease, True)
+                self.table[key].opencontext.Increase(dincrease, True)
         if increase_done:
             self._reporter.append_text(
                 " ".join(
@@ -500,7 +449,7 @@ class ChessDatabaseDeferred:
         return self._notional_record_counts
 
     def report_plans_for_estimate(self, estimates, reporter):
-        """Calculate and report file size adjustments to do import
+        """Calculate and report file size adjustments to do import.
 
         Note the reporter and headline methods for initial report and possible
         later recalculations.
@@ -514,7 +463,7 @@ class ChessDatabaseDeferred:
         self._report_plans_for_estimate(estimates=estimates)
 
     def _report_plans_for_estimate(self, estimates=None):
-        """Recalculate and report file size adjustments to do import
+        """Recalculate and report file size adjustments to do import.
 
         Create dictionary of effective game counts for sizing Games file.
         This will be passed to the import job which will increase Table B and
@@ -537,12 +486,7 @@ class ChessDatabaseDeferred:
             bytes_per_game,
             positions_per_game,
             pieces_per_game,
-            errorcount,
-            bytes_per_error,
-            estimate,
-            gamesamplecount,
-            errorsamplecount,
-        ) = self._import_estimates[:9]
+        ) = self._import_estimates[:4]
         brecppg = self.table[GAMES_FILE_DEF].filedesc[BRECPPG]
         d_count = (gamecount * (positions_per_game + pieces_per_game)) // (
             POSITIONS_PER_GAME * (1 + PIECES_PER_POSITION)
@@ -558,14 +502,14 @@ class ChessDatabaseDeferred:
         }
         append_text("Current file size and free space:")
         free = dict()
-        sizes, increases = self.get_database_table_sizes(
+        sizes, increases = self._get_database_table_sizes(
             files=self._notional_record_counts
         )
-        for fn, ds in sizes.items():
-            bsize, bused, dsize, dused = ds
+        for filename, bdsize in sizes.items():
+            bsize, bused, dsize, dused = bdsize
             bused = max(0, bused)
-            free[fn] = (bsize - bused, dsize - dused)
-            append_text_only(fn)
+            free[filename] = (bsize - bused, dsize - dused)
+            append_text_only(filename)
             append_text_only(
                 " ".join(("Current data area size", str(bsize), "pages"))
             )
@@ -584,32 +528,34 @@ class ChessDatabaseDeferred:
             )
         append_text_only("")
         append_text("File space needed for import:")
-        for fn, fc in self._notional_record_counts.items():
-            append_text_only(fn)
-            b, d = self.get_pages_for_record_counts(fc)
+        for filename, nr_count in self._notional_record_counts.items():
+            append_text_only(filename)
+            b_pages, d_pages = self._get_pages_for_record_counts(nr_count)
             append_text_only(
-                " ".join(("Estimated", str(b), "pages needed for data"))
+                " ".join(("Estimated", str(b_pages), "pages needed for data"))
             )
             append_text_only(
-                " ".join(("Estimated", str(d), "pages needed for indexes"))
+                " ".join(
+                    ("Estimated", str(d_pages), "pages needed for indexes")
+                )
             )
         append_text_only("")
         append_text("File size increases planned and free space when done:")
-        for fn, ti in increases.items():
-            bi, di = ti
-            bf, df = free[fn]
-            append_text_only(fn)
+        for filename, increments in increases.items():
+            b_incr, d_incr = increments
+            b_free, d_free = free[filename]
+            append_text_only(filename)
             append_text_only(
-                " ".join(("Data area increase", str(bi), "pages"))
+                " ".join(("Data area increase", str(b_incr), "pages"))
             )
             append_text_only(
-                " ".join(("Index area increase", str(di), "pages"))
+                " ".join(("Index area increase", str(d_incr), "pages"))
             )
             append_text_only(
-                " ".join(("Data area free", str(bi + bf), "pages"))
+                " ".join(("Data area free", str(b_incr + b_free), "pages"))
             )
             append_text_only(
-                " ".join(("Index area free", str(di + df), "pages"))
+                " ".join(("Index area free", str(d_incr + d_free), "pages"))
             )
         append_text_only("")
         append_text_only(
@@ -626,8 +572,7 @@ class ChessDatabaseDeferred:
         append_text_only("")
 
 
-class ChessDatabase(ChessDatabaseDeferred, dptdu_database.Database):
-
+class ChessDatabase(Archivedu, ChessDatabaseDeferred):
     """Provide single-step deferred update for a database of games of chess."""
 
 
@@ -636,6 +581,9 @@ if __name__ == "__main__":
     import tkinter.ttk
     import tkinter.filedialog
 
+    from solentware_bind.gui.bindings import Bindings
+
+    binder = Bindings()
     root = tkinter.Tk()
     root.wm_title("Sample do_deferred_updates")
     frame = tkinter.ttk.Frame(master=root)
@@ -651,29 +599,51 @@ if __name__ == "__main__":
         text.insert(tkinter.END, "No database selected\n")
 
     def quit_(*a):
+        """Destroy application."""
+        del a
         root.destroy()
 
     def show_menu(event=None):
+        """Post popup menu at pointer location."""
         menu.tk_popup(*event.widget.winfo_pointerxy())
 
     menu = tkinter.Menu(master=root, tearoff=False)
     if databasepath:
-        filepath = None
 
-        def do_function(dbp, fp):
-            chess_dptdu(dbp, fp)
+        class _FilePath:
+            """Wrap filepath as a class attribute.
+
+            pylint by default reports problems with filepath as a module
+            constant and as a global in the proceed() method.
+
+            Class attributes are allowed any format by pylint by default.
+            """
+
+            filepath = None
+
+        def do_function(dbp, pgnpath):
+            """Run chess_dptdu with database at dbp and PGN file at fp."""
+            chess_dptdu(dbp, pgnpath)
             text.insert(tkinter.END, "Process finished\nProceed or Quit?\n\n")
 
         def proceed(*a):
-            global filepath
+            """Run a process by the do_function function.
+
+            *a soaks up any arguments: in particular event if proceed is
+            invoked by KeyPress rather than a menu command.
+
+            """
+            del a
+            filepath = _FilePath.filepath  # Used to be 'global filepath'.
             if filepath:
                 text.insert(tkinter.END, "\nProcess started, please wait.\n")
                 text.after(1, do_function, *(databasepath, [filepath]))
-                filepath = None
+                _FilePath.filepath = None
             elif databasepath:
                 filepath = tkinter.filedialog.askopenfilename(
                     parent=root, title="Select data file", initialdir="~"
                 )
+                _FilePath.filepath = filepath
                 if filepath:
                     text.insert(tkinter.END, "Data file: " + filepath + "\n")
                 else:
@@ -688,14 +658,14 @@ if __name__ == "__main__":
         text.insert(
             tkinter.END, "\nRight-click to proceed after each step\n\n"
         )
-        text.bind("<Alt-KeyPress-F2>", proceed)
-        text.bind("<Alt-KeyPress-F11>", quit_)
-        text.bind("<ButtonPress-3>", show_menu)
+        binder.bind(text, "<Alt-KeyPress-F2>", function=proceed)
+        binder.bind(text, "<Alt-KeyPress-F11>", function=quit_)
+        binder.bind(text, "<ButtonPress-3>", function=show_menu)
     else:
         menu.add_separator()
         menu.add_command(label="Quit", command=quit_, accelerator="Alt F11")
         menu.add_separator()
         text.insert(tkinter.END, "\nRight-click to quit\n")
-        text.bind("<Alt-KeyPress-F11>", quit_)
-        text.bind("<ButtonPress-3>", show_menu)
+        binder.bind(text, "<Alt-KeyPress-F11>", function=quit_)
+        binder.bind(text, "<ButtonPress-3>", function=show_menu)
     root.mainloop()
