@@ -2,8 +2,7 @@
 # Copyright 2011 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Define User Interface for deferred update process.
-"""
+"""Define User Interface for deferred update process."""
 
 import sys
 import os
@@ -17,7 +16,8 @@ import time
 
 from solentware_misc.core import callthreadqueue
 from solentware_misc.gui.tasklog import LogText
-from solentware_misc.gui.exceptionhandler import ExceptionHandler
+
+from solentware_bind.gui.bindings import Bindings
 
 from pgn_read.core.parser import PGN
 
@@ -27,7 +27,6 @@ from .. import (
     APPLICATION_NAME,
 )
 from ..core.filespec import GAMES_FILE_DEF
-from .fonts import _get_default_font_actual
 
 # Time taken to parse a sample of a PGN file is measured.
 # Number of games in file is estimated from number of bytes used in game scores
@@ -51,7 +50,7 @@ from .fonts import _get_default_font_actual
 _DATABASE_UPDATE_FACTOR = 5
 
 
-class ChessDeferredUpdate(ExceptionHandler):
+class ChessDeferredUpdate(Bindings):
     """Connect a chess database with User Interface for deferred update."""
 
     def __init__(
@@ -64,7 +63,7 @@ class ChessDeferredUpdate(ExceptionHandler):
         sample - estimate size of import from first 'sample' games in PGN file
 
         """
-        super(ChessDeferredUpdate, self).__init__()
+        super().__init__()
         self.queue = callthreadqueue.CallThreadQueue()
         self.reportqueue = queue.Queue(maxsize=1)
 
@@ -109,7 +108,7 @@ class ChessDeferredUpdate(ExceptionHandler):
             underline=0,
             command=self.try_command(
                 # self.quit_before_import_started, self.buttonframe))
-                self.quit_import,
+                self._quit_import,
                 self.buttonframe,
             ),
         )
@@ -119,7 +118,7 @@ class ChessDeferredUpdate(ExceptionHandler):
             text="Import with Backups",
             underline=12,
             command=self.try_command(
-                self.do_import_with_backup, self.buttonframe
+                self._do_import_with_backup, self.buttonframe
             ),
         )
         backup.pack(side=tkinter.RIGHT, padx=12)
@@ -128,35 +127,50 @@ class ChessDeferredUpdate(ExceptionHandler):
             text="Import",
             underline=0,
             command=self.try_command(
-                self.do_import_without_backup, self.buttonframe
+                self._do_import_without_backup, self.buttonframe
             ),
         )
         import_.pack(side=tkinter.RIGHT, padx=12)
 
         # See comment near end of this class definition for explanation of this
-        # change.  Replacing Text by LogText fixes the majority of the problems.
+        # change.  Replacing Text by LogText fixes the majority of the
+        # problems.
         # Consequential changes, self.append_text to self.report.append_text
         # mainly, are not marked.
         # Added 07 August 2016:
+        # Edited 12 October 2022 when all tkinter.Text arguments put in cnf.
         # _get_default_font_actual() value used as cnf to avoid picking fonts
-        # like 'Chess Cases' as default font when running under Wine from
+        # like 'Chess Cases' as default font, when running under Wine, from
         # ~/.wine/drive_c/windows/Fonts or /usr/local/share/fonts.
-        # The cnf is not needed under Microsoft Windows or unix-like OS.
+        # The _get_default_font_actual() value is not needed in cnf otherwise.
+        # cnf = _get_default_font_actual(tkinter.Text) is not accepted as an
+        # argument by tkinter.Text().  It seems this argument was ignored
+        # previously en-route to the Text() call.
         self.report = LogText(
             master=self.root,
-            wrap=tkinter.WORD,
-            undo=tkinter.FALSE,
             get_app=self,
-            cnf=_get_default_font_actual(tkinter.Text),
+            cnf=dict(wrap=tkinter.WORD, undo=tkinter.FALSE),
         )
         self.report.focus_set()
-        self.report.bind("<Alt-b>", self.try_event(self.do_import_with_backup))
-        self.report.bind(
-            "<Alt-i>", self.try_event(self.do_import_without_backup)
+        self.bind(
+            self.report,
+            "<Alt-b>",
+            function=self.try_event(self._do_import_with_backup),
+        )
+        self.bind(
+            self.report,
+            "<Alt-i>",
+            function=self.try_event(self._do_import_without_backup),
+        )
+        self.bind(
+            self.report, "<Alt-q>", function=self.try_event(self._quit_import)
         )
-        self.report.bind("<Alt-q>", self.try_event(self.quit_import))
         self.database.add_import_buttons(
-            self.buttonframe, self.try_command, self.try_event, self.report
+            self.buttonframe,
+            self.try_command,
+            self.try_event,
+            self.bind,
+            self.report,
         )
 
         self.report.tag_configure(
@@ -183,14 +197,13 @@ class ChessDeferredUpdate(ExceptionHandler):
         self.root.update()
         self.root.deiconify()
         self.__run_ui_task_from_queue(1000)
-        self.root.after(100, self.try_command(self.run_allow, self.root))
+        self.root.after(100, self.try_command(self._run_allow, self.root))
         self.root.mainloop()
 
-    def allow_import(self):
+    def _allow_import(self):
         """Do checks for database engine and return True if import allowed."""
-
         # The close_database() in finally clause used to be the first statement
-        # after runjob() definition in run_import() method.  An exception was
+        # after runjob() definition in _run_import() method.  An exception was
         # raised using the sqlite3 module because run_input() is run in a
         # different thread from allow_input().  Earlier versions of chessdu did
         # not attempt to close the connection, hiding the problem.
@@ -198,13 +211,13 @@ class ChessDeferredUpdate(ExceptionHandler):
         # an interface to Berkeley DB or DPT.
         self.database.open_database()
         try:
-            if not self.estimate_games_in_import():
+            if not self._estimate_games_in_import():
                 self.report.append_text("There are no games to import.")
                 self.report.append_text_only("")
                 return None
-            if self.allow_time():
+            if self._allow_time():
                 self.database.report_plans_for_estimate(
-                    self.get_pgn_file_estimates(), self.report
+                    self._get_pgn_file_estimates(), self.report
                 )
                 return True
             self.report.append_text("Unable to estimate time to do import.")
@@ -213,7 +226,7 @@ class ChessDeferredUpdate(ExceptionHandler):
         finally:
             self.database.close_database()
 
-    def allow_time(self):
+    def _allow_time(self):
         """Ask is deferred update to proceed if game count is estimated.
 
         The time taken will vary significantly depending on environment.
@@ -277,13 +290,14 @@ class ChessDeferredUpdate(ExceptionHandler):
         self.report.append_text_only("")
         return True
 
-    def do_import_with_backup(self, event=None):
+    def _do_import_with_backup(self, event=None):
         """Run import thread if allowed and not already run.
 
         event is ignored and is present for compatibility between button click
         and keypress.
 
         """
+        del event
         if self._import_job:
             return
         names, exists = self.database.get_archive_names(
@@ -295,13 +309,14 @@ class ChessDeferredUpdate(ExceptionHandler):
                 title="Import Backup",
                 message="".join(
                     (
-                        "Import backups of the following files already exist.\n\n",
+                        "Import backups of the following files already ",
+                        "exist.\n\n",
                         "\n".join(exists),
-                        "\n\nThis may mean an earlier Import action failed and ",
-                        'has not yet been resolved.\n\nClick "Ok" to delete ',
-                        "these backups and create new ones before doing the ",
-                        "Import.  These backups will be deleted if the Import ",
-                        "succeeds.\n\nClick ",
+                        "\n\nThis may mean an earlier Import action failed ",
+                        'and has not yet been resolved.\n\nClick "Ok" to ',
+                        "delete these backups and create new ones before ",
+                        "doing the Import.  These backups will be deleted ",
+                        "if the Import succeeds.\n\nClick ",
                         '"Cancel" to leave things as they are.',
                     )
                 ),
@@ -331,15 +346,16 @@ class ChessDeferredUpdate(ExceptionHandler):
             timestamp=False,
         )
         self.report.append_text_only("")
-        self.run_import(backup=True, names=names)
+        self._run_import(backup=True, names=names)
 
-    def do_import_without_backup(self, event=None):
+    def _do_import_without_backup(self, event=None):
         """Run import thread if allowed and not already run.
 
         event is ignored and is present for compatibility between button click
         and keypress.
 
         """
+        del event
         if self._import_job:
             return
         names, exists = self.database.get_archive_names(
@@ -351,13 +367,14 @@ class ChessDeferredUpdate(ExceptionHandler):
                 title="Import Backup",
                 message="".join(
                     (
-                        "Import backups of the following files already exist.\n\n",
+                        "Import backups of the following files already ",
+                        "exist.\n\n",
                         "\n".join(exists),
-                        "\n\nThis may mean an earlier Import action failed and ",
-                        'has not yet been resolved.\n\nClick "Ok" to delete ',
-                        "these backups and create new ones before doing the ",
-                        "Import.  These backups will be deleted if the Import ",
-                        "succeeds.\n\nClick ",
+                        "\n\nThis may mean an earlier Import action failed ",
+                        'and has not yet been resolved.\n\nClick "Ok" to ',
+                        "delete these backups and create new ones before ",
+                        "doing the Import.  These backups will be deleted ",
+                        "if the Import succeeds.\n\nClick ",
                         '"Cancel" to leave things as they are.',
                     )
                 ),
@@ -379,14 +396,14 @@ class ChessDeferredUpdate(ExceptionHandler):
                 ("Please confirm the import is to be done without backups.",)
             ),
         ):
+            # self.report.append_text(
+            #     "The import will be done without taking backups."
+            # )
+            # self.report.append_text_only("")
             return
-            self.report.append_text(
-                "The import will be done without taking backups."
-            )
-            self.report.append_text_only("")
-        self.run_import(backup=False, names=names)
+        self._run_import(backup=False, names=names)
 
-    def estimate_games_in_import(self):
+    def _estimate_games_in_import(self):
         """Estimate import size from the first sample games in import files."""
         self.estimate_data = False
         text_file_size = sum([os.path.getsize(pp) for pp in sys.argv[2:]])
@@ -401,17 +418,16 @@ class ChessDeferredUpdate(ExceptionHandler):
         piecemovecount = 0
         estimate = False
         time_start = time.monotonic()
-        for pp in sys.argv[2:]:
+        for pgnfile in sys.argv[2:]:
             if gamecount + errorcount >= self.sample:
                 estimate = True
                 break
-            source = open(pp, "r", encoding="iso-8859-1")
-            try:
+            with open(pgnfile, "r", encoding="iso-8859-1") as source:
                 for rcg in reader.read_games(source):
                     if gamecount + errorcount >= self.sample:
                         estimate = True
                         break
-                    if len(rcg._text):
+                    if len(rcg.pgn_text):
                         rawtokenlen = rcg.end_char - rcg.start_char
                     else:
                         rawtokenlen = 0
@@ -425,8 +441,6 @@ class ChessDeferredUpdate(ExceptionHandler):
                         piecesquaremovecount += len(rcg.piecesquaremovekeys)
                         piecemovecount += len(rcg.piecemovekeys)
                     totallen += rawtokenlen
-            finally:
-                source.close()
         time_end = time.monotonic()
         if estimate:
             try:
@@ -507,13 +521,13 @@ class ChessDeferredUpdate(ExceptionHandler):
 
         # positions_per_game == 0 if there are no valid games.
         ppp = "Not a number"
-        for c, t in (
+        for count, text in (
             (pieces_per_game, "Pieces per position:"),
             (piecetypes_per_game, "Piece types per position:"),
         ):
             if positions_per_game:
-                ppp = str(c // positions_per_game)
-            self.report.append_text(" ".join((t, ppp)), timestamp=False)
+                ppp = str(count // positions_per_game)
+            self.report.append_text(" ".join((text, ppp)), timestamp=False)
         self.report.append_text("", timestamp=False)
 
         # Check if import can proceed
@@ -572,12 +586,13 @@ class ChessDeferredUpdate(ExceptionHandler):
         return bool(self.estimate_data)
 
     # Override ChessException method as ChessUI class is not used.
-    # May be wrong now solentware_misc ExceptionHandler is used.
+    # May be wrong now solentware_misc Bindings is used.
     def get_error_file_name(self):
         """Return the exception report file name."""
         return os.path.join(sys.argv[1], ERROR_LOG)
 
-    def get_pgn_file_estimates(self):
+    def _get_pgn_file_estimates(self):
+        """Return the estimates of object counts for a PGN file."""
         return self.estimate_data
 
     def quit_after_import_started(self):
@@ -590,33 +605,34 @@ class ChessDeferredUpdate(ExceptionHandler):
                     "The import has been started.\n\n",
                     APPLICATION_NAME,
                     " will attempt ",
-                    "to restore the files using the backups if they were taken.",
-                    "\n\nDo you want to abandon the import?",
+                    "to restore the files using the backups if they were ",
+                    "taken.\n\nDo you want to abandon the import?",
                 )
             ),
         ):
             self.root.destroy()
 
-    def quit_import(self, event=None):
+    def _quit_import(self, event=None):
         """Quit process.
 
         event is ignored and is present for compatibility between button click
         and keypress.
 
         """
+        del event
         if tkinter.messagebox.askyesno(
             parent=self.root, title="Quit Import", message=self._quit_message
         ):
             self.root.destroy()
 
-    def run_allow(self):
+    def _run_allow(self):
         """Run import thread if allowed and not already run."""
         if self._allow_job:
             return
         self._allow_job = True
-        self.queue.put_method(self.try_thread(self.allow_import, self.root))
+        self.queue.put_method(self.try_thread(self._allow_import, self.root))
 
-    def run_import(self, backup=None, names=None):
+    def _run_import(self, backup=None, names=None):
         """Invoke method to do the deferred update and display job status.
 
         backup - the answer given to the 'take backups' prompt
@@ -637,7 +653,8 @@ class ChessDeferredUpdate(ExceptionHandler):
                         self.report.append_text(
                             "".join(
                                 (
-                                    "The existing backup does not look like a ",
+                                    "The existing backup does not ",
+                                    "look like a ",
                                     APPLICATION_NAME,
                                     " backup.",
                                 )
@@ -662,8 +679,18 @@ class ChessDeferredUpdate(ExceptionHandler):
                 status = False
                 try:
                     status = self.dumethod(*a)
-                except:
-                    write_error_to_log()
+                except Exception:
+                    try:
+                        write_error_to_log()
+                    except Exception as error:
+                        raise SystemExit(
+                            " reporting exception in ".join(
+                                ("Exception while", APPLICATION_NAME)
+                            )
+                        ) from error
+                    raise SystemExit(
+                        "Exception reported in " + APPLICATION_NAME
+                    ) from error
                 self.report.append_text("Import finished.")
                 self.report.append_text_only("")
                 if not status:
@@ -671,8 +698,8 @@ class ChessDeferredUpdate(ExceptionHandler):
                         self.report.append_text(
                             "".join(
                                 (
-                                    "Problem encountered doing import. Backups are ",
-                                    "retained for recovery.",
+                                    "Problem encountered doing import. ",
+                                    "Backups are retained for recovery.",
                                 )
                             )
                         )
@@ -680,8 +707,8 @@ class ChessDeferredUpdate(ExceptionHandler):
                         self.report.append_text(
                             "".join(
                                 (
-                                    "Problem encountered doing import. No backups ",
-                                    "available.",
+                                    "Problem encountered doing import. ",
+                                    "No backups available.",
                                 )
                             )
                         )
@@ -698,7 +725,8 @@ class ChessDeferredUpdate(ExceptionHandler):
                         self.report.append_text_only(
                             "".join(
                                 (
-                                    "The existing backup does not look like a ",
+                                    "The existing backup does not ",
+                                    "look like a ",
                                     APPLICATION_NAME,
                                     " backup.",
                                 )
@@ -716,11 +744,18 @@ class ChessDeferredUpdate(ExceptionHandler):
                         "\n\nDo you want to dismiss the import log?",
                     )
                 )
-            except:
+            except Exception as error:
                 try:
                     write_error_to_log()
-                except:
-                    pass
+                except Exception as error:
+                    raise SystemExit(
+                        " reporting exception in ".join(
+                            ("Exception while", APPLICATION_NAME)
+                        )
+                    ) from error
+                raise SystemExit(
+                    "Exception reported in " + APPLICATION_NAME
+                ) from error
 
         self._import_job = True
         self.queue.put_method(
@@ -750,19 +785,27 @@ class ChessDeferredUpdate(ExceptionHandler):
     # change.
 
     def __call__(self):
-        """ """
+        """Return self allowing the construct <instance>()."""
         return self
 
     def get_reportqueue(self):
-        """ """
+        """Return queue from which reports to be displayed are taken.
+
+        Tasks run from self.queue place responses on this queue.
+
+        """
         return self.reportqueue
 
     def get_thread_queue(self):
-        """ """
+        """Return queue on which tasks to be run are placed.
+
+        A task runner takes tasks from this queue.
+
+        """
         return self.queue
 
     def __run_ui_task_from_queue(self, interval):
-        """Do all queued tasks then wake-up after interval"""
+        """Do all queued tasks then wake-up after interval."""
         while True:
             try:
                 method, args, kwargs = self.reportqueue.get_nowait()
@@ -779,9 +822,8 @@ class ChessDeferredUpdate(ExceptionHandler):
 
 def write_error_to_log():
     """Write the exception to the error log with a time stamp."""
-    f = open(os.path.join(sys.argv[1], ERROR_LOG), "a")
-    try:
-        f.write(
+    with open(os.path.join(sys.argv[1], ERROR_LOG), "a") as file:
+        file.write(
             "".join(
                 (
                     "\n\n\n",
@@ -800,5 +842,3 @@ def write_error_to_log():
                 )
             )
         )
-    finally:
-        f.close()
