@@ -16,13 +16,15 @@ import tkinter
 import tkinter.messagebox
 
 from ..core.cqlstatement import CQLStatement
-from .eventspec import EventSpec
 from .blanktext import NonTagBind, BlankText
 from .sharedtext import SharedText, SharedTextEngineText, SharedTextScore
 
 
-class CQLText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
+class CQLTextListGamesError(Exception):
+    """Exception class for display of lists of games."""
 
+
+class CQLText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
     """ChessQL statement widget.
 
     panel is used as the panel argument for the super().__init__ call.
@@ -51,9 +53,6 @@ class CQLText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
         self.ui = ui
         self.itemgrid = itemgrid
 
-        # The popup menus for the ChessQL statement.
-        self.primary_activity_popup = None
-
         # Selection rule parser instance to process text.
         self.cql_statement = CQLStatement()
         # Not sure this is needed or wanted.
@@ -70,9 +69,9 @@ class CQLText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
         if not self._is_text_editable:
             self.score.configure(state=tkinter.NORMAL)
         self.score.delete("1.0", tkinter.END)
-        self.map_cql_statement()
+        self._map_cql_statement()
         if self._most_recent_bindings != NonTagBind.NO_EDITABLE_TAGS:
-            self.bind_for_primary_activity()
+            self._bind_for_primary_activity()
         if not self._is_text_editable:
             self.score.configure(state=tkinter.DISABLED)
         if reset_undo:
@@ -83,18 +82,18 @@ class CQLText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
         self.ui.statusbar.set_status_text(self.cql_statement.get_name_text())
 
     def get_name_cql_statement_text(self):
-        """ """
+        """Return text from CQL statement Text widget."""
         text = self.score.get("1.0", tkinter.END).strip()
         return text
 
-    def map_cql_statement(self):
-        """ """
+    def _map_cql_statement(self):
+        """Convert tokens to text and show in CQL statement Text widget."""
         # No mapping of tokens to text in widget (yet).
         self.score.insert(
             tkinter.INSERT, self.cql_statement.get_name_statement_text()
         )
 
-    def get_partial_key_cql_statement(self):
+    def _get_partial_key_cql_statement(self):
         """Return ChessQL statement for use as partial key."""
         if self.cql_statement.is_statement():
 
@@ -102,8 +101,7 @@ class CQLText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
             # return tuple(self.cql_statement.position)
             return self.cql_statement.get_statement_text()  # Maybe!
 
-        else:
-            return False
+        return False
 
     def refresh_game_list(self):
         """Display games with position matching selected ChessQL statement."""
@@ -128,8 +126,9 @@ class CQLText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
                     msg = "".join(
                         (
                             "Unable to list games for ChessQL statement, ",
-                            "probably because an 'empty square' is in the query ",
-                            "(eg '.a2-3'):\n\nThe reported  error is:\n\n",
+                            "probably because an 'empty square' is in the ",
+                            "query (eg '.a2-3'):\n\n",
+                            "The reported  error is:\n\n",
                             str(exc),
                         )
                     )
@@ -147,21 +146,7 @@ class CQLText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
                     title="ChessQL Statement",
                     message=msg,
                 )
-            except Exception as exc:
-                msg = "".join(
-                    (
-                        "Unable to list games for ChessQL statement:\n\n",
-                        "The reported error is:\n\n",
-                        str(exc),
-                    )
-                )
-                grid.datasource.get_cql_statement_games(None, None)
-                tkinter.messagebox.showinfo(
-                    parent=self.ui.get_toplevel(),
-                    title="ChessQL Statement",
-                    message=msg,
-                )
-        grid.partial = self.get_partial_key_cql_statement()
+        grid.partial = self._get_partial_key_cql_statement()
         # grid.rows = 1
         grid.load_new_index()
 
