@@ -2,25 +2,19 @@
 # Copyright 2015 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Widget to display a game selection rule.
-"""
+"""Widget to display a game selection rule."""
 
 import tkinter
 import tkinter.messagebox
 
-from .constants import (
-    START_SELECTION_RULE_MARK,
-)
 from ..core.querystatement import QueryStatement
-from .eventspec import EventSpec
-from .gamerow import make_ChessDBrowGame
+from .gamerow import chess_db_row_game
 from ..core.chessrecord import ChessDBrecordGameTags
 from .blanktext import NonTagBind, BlankText
 from .sharedtext import SharedText, SharedTextEngineText, SharedTextScore
 
 
 class QueryText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
-
     """Game selection rule widget.
 
     panel is used as the panel argument for the super().__init__ call.
@@ -49,9 +43,6 @@ class QueryText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
         self.ui = ui
         self.itemgrid = itemgrid
 
-        # The popup menus for the selection rule.
-        self.primary_activity_popup = None
-
         # Selection rule parser instance to process text.
         self.query_statement = QueryStatement()
         if ui.base_games.datasource:
@@ -68,9 +59,9 @@ class QueryText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
         if not self._is_text_editable:
             self.score.configure(state=tkinter.NORMAL)
         self.score.delete("1.0", tkinter.END)
-        self.map_query_statement()
+        self._map_initial_query_statement()
         if self._most_recent_bindings != NonTagBind.NO_EDITABLE_TAGS:
-            self.bind_for_primary_activity()
+            self._bind_for_primary_activity()
         if not self._is_text_editable:
             self.score.configure(state=tkinter.DISABLED)
         if reset_undo:
@@ -81,12 +72,12 @@ class QueryText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
         self.ui.statusbar.set_status_text(self.query_statement.get_name_text())
 
     def get_name_query_statement_text(self):
-        """ """
+        """Return text from query statement Text widget."""
         text = self.score.get("1.0", tkinter.END).strip()
         return text
 
-    def map_query_statement(self):
-        """ """
+    def _map_initial_query_statement(self):
+        """Convert tokens to text and show in query statement Text widget."""
         # No mapping of tokens to text in widget (yet).
         self.score.insert(
             tkinter.INSERT,
@@ -105,37 +96,39 @@ class QueryText(SharedText, SharedTextEngineText, SharedTextScore, BlankText):
                 grid.datasource.dbhome,
                 self.ui.base_games.datasource.dbset,
                 self.ui.base_games.datasource.dbset,
-                make_ChessDBrowGame(self.ui),
+                chess_db_row_game(self.ui),
             ),
             self.ui.base_games.on_data_change,
         )
-        qs = self.query_statement
-        if qs.where_error:
+        statement = self.query_statement
+        if statement.where_error:
             self.ui.base_games.datasource.get_selection_rule_games(None)
             self.ui.base_games.load_new_index()
             tkinter.messagebox.showerror(
                 parent=self.ui.get_toplevel(),
                 title="Display Game Selection Rule",
-                message=qs.where_error.get_error_report(grid.datasource),
+                message=statement.where_error.get_error_report(
+                    grid.datasource
+                ),
             )
-        elif qs.where:
-            qs.where.evaluate(
+        elif statement.where:
+            statement.where.evaluate(
                 grid.datasource.dbhome.record_finder(
                     grid.datasource.dbset, ChessDBrecordGameTags
                 )
             )
 
             # Workaround problem with query ''.  See Where.evaluate() also.
-            r = qs.where.node.get_root().result
-            if r is None:
+            result = statement.where.node.get_root().result
+            if result is None:
                 self.ui.base_games.datasource.get_selection_rule_games(None)
             else:
                 self.ui.base_games.datasource.get_selection_rule_games(
-                    r.answer
+                    result.answer
                 )
             self.ui.base_games.load_new_index()
 
-        elif qs.get_query_statement_text():
+        elif statement.get_query_statement_text():
             self.ui.base_games.load_new_index()
         # else:
         #    tkinter.messagebox.showinfo(
