@@ -20,12 +20,9 @@ text).
 
 """
 
-import tkinter
-import tkinter.messagebox
-
 from solentware_grid.core.dataclient import DataNotify
 
-from solentware_misc.gui.exceptionhandler import ExceptionHandler
+from solentware_bind.gui.bindings import Bindings
 
 from ..core.constants import TAG_OPENING
 from .repertoire import Repertoire
@@ -34,10 +31,10 @@ from ..core.chessrecord import ChessDBrecordRepertoireUpdate
 from .eventspec import EventSpec
 from .display import Display
 from .displaypgn import ShowPGN, InsertPGN, EditPGN, DisplayPGN
+from .game import Game
 
 
-class _RepertoireDisplay(ExceptionHandler, Display):
-
+class _RepertoireDisplay(ShowPGN, Game, Bindings, DataNotify, Display):
     """Extend and link PGN repertoire text to database.
 
     sourceobject - link to database.
@@ -103,12 +100,15 @@ class _RepertoireDisplay(ExceptionHandler, Display):
     # to displaypgn.ShowPGN class.
     @property
     def ui_displayed_items(self):
+        """Return manager of widgets displaying a repertoire record."""
         return self.ui.repertoire_items
 
-    # Defined so cycle_item and give_focus_to_widget methods can be shared by
-    # gamedisplay._GameDisplay and repertoiredisplay._RepertoireDisplay classes.
+    # Defined so _cycle_item and give_focus_to_widget methods can be shared by
+    # gamedisplay._GameDisplay and repertoiredisplay._RepertoireDisplay
+    # classes.
     @property
     def ui_configure_item_list_grid(self):
+        """Return function to configure repertoire grid to fit text."""
         return self.ui.configure_repertoire_grid
 
     # ui_base_table and mark_partial_positions_to_be_recalculated defined
@@ -118,16 +118,18 @@ class _RepertoireDisplay(ExceptionHandler, Display):
 
     @property
     def ui_base_table(self):
+        """Return the User Interface TagRosterGrid object."""
         return self.ui.base_repertoires
 
     @property
     def ui_items_in_toplevels(self):
+        """Return the User Interface objects in Toplevels."""
         return self.ui.games_and_repertoires_in_toplevels
 
     def mark_partial_positions_to_be_recalculated(self, datasource=None):
-        pass
+        """Do nothing.  Exists for compatibility with game display."""
 
-    def get_navigation_events(self):
+    def _get_navigation_events(self):
         """Return event description tuple for navigation from repertoire."""
         return (
             (
@@ -163,9 +165,9 @@ class _RepertoireDisplay(ExceptionHandler, Display):
             ),
             (
                 EventSpec.repertoiredisplay_to_previous_repertoire,
-                self.prior_item,
+                self._prior_item,
             ),
-            (EventSpec.repertoiredisplay_to_next_repertoire, self.next_item),
+            (EventSpec.repertoiredisplay_to_next_repertoire, self._next_item),
             (EventSpec.tab_traverse_forward, self.traverse_forward),
             (EventSpec.tab_traverse_backward, self.traverse_backward),
             # No traverse_round because Alt-F8 toggles repertoire and analysis.
@@ -173,13 +175,14 @@ class _RepertoireDisplay(ExceptionHandler, Display):
 
     def delete_item_view(self, event=None):
         """Remove repertoire item from screen."""
+        del event
         self.set_data_source()
         self.ui.delete_repertoire_view(self)
 
     def on_game_change(self, instance):
         """Prevent update from self if instance refers to same record."""
         if self.sourceobject is not None:
-            self.patch_pgn_score_to_fit_record_change_and_refresh_grid(
+            self._patch_pgn_score_to_fit_record_change_and_refresh_grid(
                 self.ui.repertoire_games, instance
             )
 
@@ -193,21 +196,9 @@ class _RepertoireDisplay(ExceptionHandler, Display):
             ):
                 self.blockchange = True
 
-    def get_text_for_statusbar(self):
-        """ """
-        return "".join(
-            (
-                "Please wait while finding games for repertoire position in ",
-                self.pgn.tags.get(TAG_OPENING, "?"),
-            )
-        )
-
-    def get_selection_text_for_statusbar(self):
-        """ """
-        return self.pgn.tags.get(TAG_OPENING, "?")
-
     def generate_popup_navigation_maps(self):
-        navigation_map = {k: v for k, v in self.get_navigation_events()}
+        """Return genenal and current widget navigation binding maps."""
+        navigation_map = dict(self._get_navigation_events())
         local_map = {
             EventSpec.scoresheet_to_analysis: self.analysis_current_item,
         }
@@ -217,7 +208,6 @@ class _RepertoireDisplay(ExceptionHandler, Display):
 class RepertoireDisplay(
     _RepertoireDisplay, DisplayPGN, ShowPGN, Repertoire, DataNotify
 ):
-
     """Display a repertoire from a database allowing delete and insert."""
 
     # Allow for structure difference between RepertoireDisplay and GameDisplay
@@ -226,28 +216,30 @@ class RepertoireDisplay(
     # Existence of this method prevents delete_game_database being used by
     # instances of superclasses of RepertoireDisplay, emulating the behaviour
     # before introduction of displaypgn module.
-    def pgn_score_original_value(self, original_value):
-
+    @staticmethod
+    def pgn_score_original_value(original_value):
+        """Set source name for original_value object."""
         # currently attracts "AttributeError: 'ChessDBvalueGameTags' has
         # no attribute 'gamesource'.
         # original.value.set_game_source(self.sourceobject.value.gamesource)
         original_value.set_game_source("No opening name")
 
-    def create_primary_activity_popup(self):
-        popup = super().create_primary_activity_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_primary_activity_popup(self):
+        """Delegate then add close command to popup and return popup menu."""
+        popup = super()._create_primary_activity_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
-    def create_select_move_popup(self):
-        popup = super().create_select_move_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_select_move_popup(self):
+        """Delegate then add close command to popup and return popup menu."""
+        popup = super()._create_select_move_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
 
 class RepertoireDisplayInsert(
     _RepertoireDisplay, InsertPGN, ShowPGN, RepertoireEdit, DataNotify
 ):
-
     """Display a repertoire from a database allowing insert.
 
     RepertoireEdit provides the widget and _RepertoireDisplay the database
@@ -257,7 +249,6 @@ class RepertoireDisplayInsert(
 
 
 class RepertoireDisplayEdit(EditPGN, RepertoireDisplayInsert):
-
     """Display a repertoire from a database allowing edit and insert."""
 
     # Allow for structure difference between RepertoireDisplay and GameDisplay
@@ -266,18 +257,20 @@ class RepertoireDisplayEdit(EditPGN, RepertoireDisplayInsert):
     # Existence of this method prevents delete_game_database being used by
     # instances of superclasses of RepertoireDisplay, emulating the behaviour
     # before introduction of displaypgn module.
-    def pgn_score_original_value(self, original_value):
-
+    @staticmethod
+    def pgn_score_original_value(original_value):
+        """Set source name for original_value object."""
         # currently attracts "AttributeError: 'ChessDBvalueGameTags' has
         # no attribute 'gamesource'.
         # original.value.set_game_source(self.sourceobject.value.gamesource)
         original_value.set_game_source("No opening name")
 
-    # set_properties_on_grids defined so update_game_database method can be
+    # _set_properties_on_grids defined so update_game_database method can be
     # shared by repertoiredisplay.RepertoireDisplayEdit and
     # gamedisplay.GameDisplayEdit classes.
     # See class attributes pgn_score_name and pgn_score_source_name too.
     # The property which returns self.ui.base_repertoires is ignored because
     # the GameDisplayEdit version of the method sets properties on all grids.
     def set_properties_on_game_grids(self, newkey):
+        """Set grid row properties of row for newkey record."""
         self.ui.base_repertoires.set_properties(newkey)
