@@ -2,32 +2,16 @@
 # Copyright 2021 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Provide classes which define methods shared by classes in the displaypgn
-and toplevelpgn modules which display Portable Game Notation (PGN) text.
+"""Provide class which switches board display between game score and analysis.
 
-The displaypgn module has classes used as superclasses in the gamedisplay and
-repertoiredisplay modules.
-
-The toplevelpgn module has classes used as superclasses in the gamedbdelete,
-gamedbdisplay, gamedbedit, gamedbshow, repertoiredbdelete, repertoiredbdisplay,
-repertoiredbedit, and repertoiredbshow, classes.
-
-All methods in the classes in this module existed as multiple copies in various
-classes in the modules named above.  They are now deleted from those modules.
-
-The classes in this module represnt the different sets of classes with methods
-in common.
-
-The ScorePGN class has methods identical in _GameDisplay, _RepertoireDisplay,
-GameDialogue, and RepertoireDialogue, now removed from those classes.
+The ScorePGN class is used to to display games and repertoires.
 
+The games and repertoires are in Portable Game Notation (PGN) text.
 """
 
 
 class ScorePGN:
-
-    """Mixin providing methods shared by the displaypgn.ShowPGN and
-    toplevelpgn.ToplevelPGN classes.
+    """Display current game or analysis position on the board.
 
     These methods display the game or repertoire PGN score, or the engine
     analysis for the PGN score.
@@ -42,7 +26,8 @@ class ScorePGN:
 
     def analysis_current_item(self, event=None):
         """Select current PGN score analysis."""
-        if self.game_position_analysis:
+        del event
+        if self._get_game_position_analysis():
             self.analysis.apply_colouring_to_variation_back_to_main_line()
         else:
             self.analysis.clear_current_range()
@@ -58,10 +43,10 @@ class ScorePGN:
         self.set_analysis_score_pointer_to_analysis_score_bindings(False)
         self.set_toggle_game_analysis_bindings(True)
         self.analysis.score.focus_set()
-        self.game_position_analysis = True
-        self.takefocus_widget = self.analysis.score
+        self._set_game_position_analysis(True)
+        self._init_takefocus_widget(self.analysis.score)
 
-    def current_pgn_score(self, cuiai):
+    def _current_pgn_score(self, cuiai):
         """Select current PGN score on display.
 
         Argument name follows history of separate functionally identical
@@ -69,7 +54,6 @@ class ScorePGN:
         and repertoiredisplay modules.
 
         """
-
         # cuiai should be referencing self given use of current_item() method,
         # but style of sibling *_item() methods is followed.
         # cuiai was cuigs in gamedisplay, and cuirs in repertoiredisplay,
@@ -88,5 +72,5 @@ class ScorePGN:
         cuiai.set_score_pointer_to_score_bindings(False)
         cuiai.set_analysis_score_pointer_to_analysis_score_bindings(True)
         cuiai.set_toggle_game_analysis_bindings(True)
-        self.takefocus_widget = self.score
+        self._init_takefocus_widget(self.score)
         cuiai.takefocus_widget.focus_set()
