@@ -2,18 +2,9 @@
 # Copyright 2021 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Provide classes which define methods shared by classes in cqltext, score,
-enginetext, and querytext modules.
-
-The methods are originally defined in classes in those modules.  All were
-identical in the CQLText and QueryText classes, and were in at most one of
-the Score and EngineText classes too as identical methods.  Methods identical
-in all four classes are in the blanktext.BlankText class.
-
-The displaytext and displaypgn module do a similar thing where it matters if
-the class is doing 'show', 'insert', 'delete', or 'edit', actions.  Methods
-in classes in this module do not care about those differences.
+"""Provide classes which define navigation methods and bindings.
 
+The classes are SharedText, SharedTextEngineText, and SharedTextScore.
 """
 
 import tkinter
@@ -22,84 +13,83 @@ from .eventspec import EventSpec
 
 
 class SharedText:
-
-    """Provide methods shared by the cqltext.CQLText and querytext.QueryText
-    classes.
+    """Provide navigation bindings for subclasses.
 
     Methods with the same name are used in one or both enginetext.EngineText
     and score.Score, but the internals are different.
 
     """
 
-    def set_primary_activity_bindings(self, switch=True):
+    def _set_primary_activity_bindings(self, switch=True):
         """Switch bindings for traversing query statement on or off."""
         self.set_event_bindings_score(
-            self.get_F10_popup_events(
-                self.post_active_menu_at_top_left, self.post_active_menu
+            self.get_f10_popup_events(
+                self._post_active_menu_at_top_left, self._post_active_menu
             ),
             switch=switch,
         )
         self.set_event_bindings_score(
-            self.get_button_events(buttonpress3=self.post_active_menu),
+            self._get_button_events(buttonpress3=self._post_active_menu),
             switch=switch,
         )
 
     def set_score_pointer_item_navigation_bindings(self, switch):
         """Set or unset pointer bindings for game navigation."""
         self.set_event_bindings_score(
-            self.get_button_events(buttonpress3=self.post_active_menu),
+            self._get_button_events(buttonpress3=self._post_active_menu),
             switch=switch,
         )
 
-    def get_primary_activity_events(self):
+    @staticmethod
+    def get_primary_activity_events():
+        """Return null tuple of navigation keypresses and callbacks."""
         return ()
 
 
 class SharedTextEngineText:
+    """Provide keypress and pointer navigation methods for subclasses.
 
-    """Provide methods shared by the cqltext.CQLText, enginetext.EngineText,
-    and querytext.QueryText, classes.
-
-    A method with the same name may be used in score.Score, but the internals
-    are different.
-
+    This is a separate hierarchy from SharedTextScore because the engine
+    stuff is in a Toplevel instance not the main application widget.
     """
 
-    def get_modifier_buttonpress_suppression_events(self):
-        """Return tuple of event binding definitions suppressing buttonpress
-        with Control, Shift, or Alt."""
+    @staticmethod
+    def _get_modifier_buttonpress_suppression_events():
+        """Return empty tuple of event binding definitions.
+
+        These events suppress buttonpress with Control, Shift, or Alt.
+
+        """
         return ()
 
-    def post_active_menu(self, event=None):
+    def _post_active_menu(self, event=None):
         """Show the popup menu for chess engine definition navigation."""
-        return self.post_menu(
+        return self._post_menu(
             self.primary_activity_popup,
-            self.create_primary_activity_popup,
-            allowed=self.is_active_item_mapped(),
+            self._create_primary_activity_popup,
+            allowed=self._is_active_item_mapped(),
             event=event,
         )
 
-    def post_active_menu_at_top_left(self, event=None):
+    def _post_active_menu_at_top_left(self, event=None):
         """Show the popup menu for chess engine definition navigation."""
         return self.post_menu_at_top_left(
             self.primary_activity_popup,
-            self.create_primary_activity_popup,
-            allowed=self.is_active_item_mapped(),
+            self._create_primary_activity_popup,
+            allowed=self._is_active_item_mapped(),
             event=event,
         )
 
 
 class SharedTextScore:
+    """Provide keypress and pointer navigation methods for subclasses.
 
-    """Provide methods shared by the cqltext.CQLText, querytext.QueryText,
-    and score.Score, classes.
-
-    A method with the same name may be used in enginetext.EngineText, but the
-    internals are different.
-
+    This is a separate hierarchy from SharedTextEngineText because the
+    engine stuff is in a Toplevel instance not the main application
+    widget.
     """
 
-    def add_cascade_menu_to_popup(
+    def _add_cascade_menu_to_popup(
         self, label, popup, bindings=None, order=None, index=tkinter.END
     ):
         """Add cascade_menu, and bindings, to popup if not already present.
@@ -112,7 +102,7 @@ class SharedTextScore:
         # Cannot see a way of asking 'Does entry exist?' other than:
         try:
             popup.index(label)
-        except:
+        except tkinter.TclError:
             cascade_menu = tkinter.Menu(master=popup, tearoff=False)
             popup.insert_cascade(label=label, menu=cascade_menu, index=index)
             if order is None:
@@ -130,7 +120,7 @@ class SharedTextScore:
 
     # Subclasses which need widget navigation in their popup menus should
     # call this method.
-    def create_widget_navigation_submenu_for_popup(self, popup):
+    def _create_widget_navigation_submenu_for_popup(self, popup):
         """Create and populate a submenu of popup for widget navigation.
 
         The commands in the submenu should switch focus to another widget.
@@ -141,45 +131,48 @@ class SharedTextScore:
         """
         navigation_map, local_map = self.generate_popup_navigation_maps()
         local_map.update(navigation_map)
-        self.add_cascade_menu_to_popup(
+        self._add_cascade_menu_to_popup(
             "Navigation", popup, bindings=local_map, order=self.binding_labels
         )
 
     # Subclasses which need dismiss widget in a menu should call this method.
-    def add_close_item_entry_to_popup(self, popup):
+    def _add_close_item_entry_to_popup(self, popup):
         """Add option to dismiss widget entry to popup.
 
         Subclasses must provide a delete_item_view method.
 
         """
-        self.set_popup_bindings(popup, self.get_close_item_events())
+        self._set_popup_bindings(popup, self._get_close_item_events())
 
-    def create_inactive_popup(self):
+    def _create_inactive_popup(self):
+        """Create popup menu for an inactive widget."""
         assert self.inactive_popup is None
         popup = tkinter.Menu(master=self.score, tearoff=False)
-        self.set_popup_bindings(popup, self.get_inactive_events())
-        self.inactive_popup = popup
+        self._set_popup_bindings(popup, self._get_inactive_events())
+        self._init_inactive_popup(popup)
         return popup
 
-    def get_inactive_button_events(self):
-        return self.get_modifier_buttonpress_suppression_events() + (
+    def _get_inactive_button_events(self):
+        """Return pointer event specifications for an inactive widget."""
+        return self._get_modifier_buttonpress_suppression_events() + (
             (EventSpec.buttonpress_1, self.give_focus_to_widget),
             (EventSpec.buttonpress_3, self.post_inactive_menu),
         )
 
     def post_inactive_menu(self, event=None):
         """Show the popup menu for a game score in an inactive item."""
-        return self.post_menu(
-            self.inactive_popup, self.create_inactive_popup, event=event
+        return self._post_menu(
+            self.inactive_popup, self._create_inactive_popup, event=event
         )
 
     def post_inactive_menu_at_top_left(self, event=None):
         """Show the popup menu for a game score in an inactive item."""
         return self.post_menu_at_top_left(
-            self.inactive_popup, self.create_inactive_popup, event=event
+            self.inactive_popup, self._create_inactive_popup, event=event
         )
 
-    def get_inactive_events(self):
+    def _get_inactive_events(self):
+        """Return keypress event specifications for an inactive widget."""
         return (
             (EventSpec.display_make_active, self.set_focus_panel_item_command),
             (EventSpec.display_dismiss_inactive, self.delete_item_view),
