@@ -2,18 +2,16 @@
 # Copyright 2021 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Provide methods shared by all classes which display games, repertoires,
-selection rules, CQL statements, and run engine commands in Toplevels.
+"""Provide classes which initialize and close record or filter rule displays.
+
+The records are games, repertoires, and rule lists.  The rules are selection
+rules, CQL statements, and run engine commands in Toplevels.
 
 """
 
 
 class ToplevelText:
-
-    """Mixin providing methods shared by all classes which display selection
-    rules, CQL statements, and run engine commands in Toplevels.
-
-    """
+    """Provide default popup menu initialisation methods for record display."""
 
     binding_labels = ()
 
@@ -24,25 +22,33 @@ class ToplevelText:
     # The Engine* classes do not have this problem, perhaps because of the
     # 'Run Engine' option or the absence of the 'main display' options.
     # The Game* and Repertoire* classes have reason for a popup here.
-    def create_widget_navigation_submenu_for_popup(self, popup):
-        pass
+    def _create_widget_navigation_submenu_for_popup(self, popup):
+        """Do nothing.
+
+        Most ToplevelText subclasses require a handler for right-click,
+        Shift F10, and Ctrl F10, events.
+
+        A null popup menu is posted unless the subclass has a reason to
+        implement a useful popup menu.
+        """
 
 
 class _ToplevelText:
+    """Provide methods shared by this module's public _ToplevelText subclasses.
 
-    """Mixin providing methods shared by at least two of the DeleteText,
-    EditText, and ShowText, classes.
-
+    The subclasses are DeleteText, EditText, and ShowText.
     """
 
-    def initialize(self):
+    def _initialize(self):
+        """Initialize the widgets and event bindings in Toplevel widget."""
         oldview = self.oldview
         self.ui_items_in_toplevels.add(oldview)
-        self.parent.wm_title(self.get_title_for_object(self.object))
-        self.initialize_item_bindings(oldview)
-        self.set_item(oldview, self.object)
+        self._set_item(oldview, self.object)
+        self.parent.wm_title(self._get_title_for_object(self.object))
+        self._initialize_item_bindings(oldview)
 
-    def initialize_item_bindings(self, item):
+    def _initialize_item_bindings(self, item):
+        """Initialize keypress and buttonpress bindings for item."""
         self.bind_buttons_to_widget(item.score)
         # item.set_score_pointer_to_score_bindings(False)
 
@@ -53,18 +59,19 @@ class _ToplevelText:
 
 
 class ShowText(_ToplevelText):
+    """Show original text."""
+
     def dialog_ok(self):
         """Close the show record toplevel."""
         if self.ui.database is None:
-            if self.ok:
-                self.ok.destroy()
-                self.ok = None
-            self.blockchange = True
+            self.destroy_dialog_on_ok_and_blockchange()
             return False
         return super().dialog_ok()
 
 
 class DeleteText(_ToplevelText):
+    """Show original text for record deletion."""
+
     def dialog_ok(self):
         """Delete record and return delete action response (True for deleted).
 
@@ -76,24 +83,25 @@ class DeleteText(_ToplevelText):
             self.status.configure(
                 text="Cannot delete because not connected to a database"
             )
-            if self.ok:
-                self.ok.destroy()
-                self.ok = None
-            self.blockchange = True
+            self.destroy_dialog_on_ok_and_blockchange()
             return False
         return super().dialog_ok()
 
 
 class EditText(_ToplevelText):
-    def initialize(self):
+    """Show original and editable text versions for record editing."""
+
+    def _initialize(self):
+        """Create widgets for the original and editable versions of text."""
         if self.oldview:
             self.ui_items_in_toplevels.add(self.oldview)
-            self.set_item(self.oldview, self.oldobject)
+            self._set_item(self.oldview, self.oldobject)
+            self._initialize_item_bindings(self.oldview)
         newview = self.newview
         self.ui_items_in_toplevels.add(newview)
-        self.set_item(newview, self.newobject)
-        self.parent.wm_title(self.get_title_for_object(self.newobject))
-        self.initialize_item_bindings(newview)
+        self._set_item(newview, self.newobject)
+        self.parent.wm_title(self._get_title_for_object(self.newobject))
+        self._initialize_item_bindings(newview)
 
     def dialog_ok(self):
         """Update record and return update action response (True for updated).
@@ -106,10 +114,7 @@ class EditText(_ToplevelText):
             self.status.configure(
                 text="Cannot update because not connected to a database"
             )
-            if self.ok:
-                self.ok.destroy()
-                self.ok = None
-            self.blockchange = True
+            self.destroy_dialog_on_ok_and_blockchange()
             return False
         return super().dialog_ok()
 
