@@ -2,8 +2,12 @@
 # Copyright 2021 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Demonstrate chess game class and methods to display PGN text, board, and
-analysis as it appears without an active chess engine."""
+"""Demonstrate chess game class and methods.
+
+This sample code will display PGN text, board, and analysis as it appears
+without an active chess engine.
+
+"""
 
 if __name__ == "__main__":
 
@@ -19,13 +23,13 @@ if __name__ == "__main__":
         """Helper to allow Game instances to work without a real UI."""
 
         def set_status_text(self, *a, **k):
-            pass
+            """Do nothing."""
 
     class DuckqueueQueue:
         """Helper to allow Game instances to work without a real UI."""
 
         def put(self, *a):
-            pass
+            """Do nothing."""
 
     class DuckcoreuciUCI:
         """Helper to allow Game instances to work without a real UI."""
@@ -49,6 +53,7 @@ if __name__ == "__main__":
         database = False
 
         def make_position_analysis_data_source(self):
+            """Return None as data analysis source."""
             return None
 
         statusbar = DuckStatusbar()
@@ -58,9 +63,12 @@ if __name__ == "__main__":
     # else, even if duplicated, to avoid this.
     # An empty Navigation entry is put in the popup menu.
     class Game(Game):
+        """Customise Game with empty popup navigation maps."""
+
         binding_labels = ()
 
         def generate_popup_navigation_maps(self):
+            """Return empty navigation maps."""
             return {}, {}
 
     root = tkinter.Tk()
@@ -86,10 +94,13 @@ if __name__ == "__main__":
                     '[Result"1-0"]',
                     "e4(d4d5c4e6Nc3)c6d4d5exd5cxd5c4Nf6c5e6Nc3b6b4a5Bf4",
                     "axb4Nb5Na6Qa4;comment to eol\nBd7",
-                    "Bc7Nxc5Qd1Qc8dxc5bxc5Nf3Qb7Nd6Bxd6Bxd6Qb6Be5Ke7Be2Ne4O-Of6Bb2Nc3",
-                    "Bxc3bxc3Qd3(Qb3)Ra3Rfb1Qa7Qc2g6Rb3d4Bc4Rxb3Bxb3Qa6a4Rb8a5e5Bd5",
+                    "Bc7Nxc5Qd1Qc8dxc5bxc5Nf3Qb7Nd6Bxd6Bxd6Qb6",
+                    "Be5Ke7Be2Ne4O-Of6Bb2Nc3",
+                    "Bxc3bxc3Qd3(Qb3)Ra3Rfb1Qa7Qc2g6Rb3d4Bc4",
+                    "Rxb3Bxb3Qa6a4Rb8a5e5Bd5",
                     "\n%The escape sequence\nRb2",
-                    "Qe4Bf5Qh4Qd3(c2(g5)Nd2Qxa5Rxa5Rb1{Comment\ncontaining newline}Nf1",
+                    "Qe4Bf5Qh4Qd3(c2(g5)Nd2Qxa5Rxa5Rb1",
+                    "{Comment\ncontaining newline}Nf1",
                     "(Nxb1c1=Q)Rxf1Kxf1Bd3)g4Rb1",
                     "Rxb1Qxb1Kg2Kd6Qxf6Kxd5<reserved\n\nfor future use>Qxe5",
                     "Kc6gxf5Qxf5Qe8Kc7Qe7Kc8Ne5c2Qxc5Kd8Qxd4",
