@@ -19,22 +19,26 @@ class DuckBoard:
     boardsquares = {}
 
     def __init__(self, ui):
+        """Set reference to ui User Interface object."""
         self.ui = ui
 
     def set_board(self, board):
-        pass
+        """Do nothing because board display is not implemented."""
 
 
 class DuckUI:
     """Helper to allow Score instances to work without a real UI."""
 
     def __init__(self, panel, *a, **k):
+        """Note panel as reference point to get top level widget."""
         self.top_pw = panel
 
     def get_toplevel(self):
+        """Return the top level widget."""
         return self.top_pw.winfo_toplevel()
 
     def get_export_filename_for_single_item(self, *a, **k):
+        """Display dialogue saying export not supported here."""
         tkinter.messagebox.showinfo(
             parent=self.get_toplevel(),
             title="Export Game",
@@ -72,10 +76,13 @@ if __name__ == "__main__":
                     '[Result"1-0"]',
                     "e4(d4d5c4e6Nc3)c6d4d5exd5cxd5c4Nf6c5e6Nc3b6b4a5Bf4",
                     "axb4Nb5Na6Qa4;comment to eol\nBd7",
-                    "Bc7Nxc5Qd1Qc8dxc5bxc5Nf3Qb7Nd6Bxd6Bxd6Qb6Be5Ke7Be2Ne4O-Of6Bb2Nc3",
-                    "Bxc3bxc3Qd3(Qb3)Ra3Rfb1Qa7Qc2g6Rb3d4Bc4Rxb3Bxb3Qa6a4Rb8a5e5Bd5",
+                    "Bc7Nxc5Qd1Qc8dxc5bxc5Nf3Qb7Nd6Bxd6Bxd6Qb6",
+                    "Be5Ke7Be2Ne4O-Of6Bb2Nc3",
+                    "Bxc3bxc3Qd3(Qb3)Ra3Rfb1Qa7Qc2g6Rb3d4Bc4",
+                    "Rxb3Bxb3Qa6a4Rb8a5e5Bd5",
                     "\n%The escape sequence\nRb2",
-                    "Qe4Bf5Qh4Qd3(c2(g5)Nd2Qxa5Rxa5Rb1{Comment\ncontaining newline}Nf1",
+                    "Qe4Bf5Qh4Qd3(c2(g5)Nd2Qxa5Rxa5Rb1",
+                    "{Comment\ncontaining newline}Nf1",
                     "(Nxb1c1=Q)Rxf1Kxf1Bd3)g4Rb1",
                     "Rxb1Qxb1Kg2Kd6Qxf6Kxd5<reserved\n\nfor future use>Qxe5",
                     "Kc6gxf5Qxf5Qe8Kc7Qe7Kc8Ne5c2Qxc5Kd8Qxd4",
