@@ -2,8 +2,7 @@
 # Copyright 2020 Roger Marsh
 # Licence: See LICENSE.txt (BSD licence)
 
-"""Create empty ChessTab database with chosen database engine and segment size.
-"""
+"""Create ChessTab database with chosen database engine and segment size."""
 
 from solentware_base.tools import create_database
 
